import cats.data
import io.circe
import java.io
import java.lang
import jpype.protocol
import org.ergoplatform.wallet.interface4j
import org.ergoplatform.wallet.settings
import scala
import scala.collection
import scala.collection.immutable
import scala.runtime
import scala.util
import scorex.util.serialization
import sigmastate.basics
import typing



class DerivationPath(scala.Product, scala.Serializable):
    def __init__(self, decodedPath: scala.collection.Seq[typing.Any], publicBranch: bool): ...
    @staticmethod
    def MasterPath() -> 'DerivationPath': ...
    @staticmethod
    def PrivateBranchMasterId() -> java.lang.String: ...
    @staticmethod
    def PublicBranchMasterId() -> java.lang.String: ...
    @staticmethod
    def apply(decodedPath: scala.collection.Seq[typing.Any], publicBranch: bool) -> 'DerivationPath': ...
    def bytes(self) -> typing.List[int]: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, decodedPath: scala.collection.Seq[typing.Any], publicBranch: bool) -> 'DerivationPath': ...
    def copy$default$1(self) -> scala.collection.Seq[typing.Any]: ...
    def copy$default$2(self) -> bool: ...
    def decodedPath(self) -> scala.collection.Seq[typing.Any]: ...
    def depth(self) -> int: ...
    def encoded(self) -> java.lang.String: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def extended(self, idx: int) -> 'DerivationPath': ...
    @staticmethod
    def fromEncoded(path: typing.Union[java.lang.String, str]) -> scala.util.Try['DerivationPath']: ...
    def hashCode(self) -> int: ...
    def increased(self) -> 'DerivationPath': ...
    def index(self) -> int: ...
    def isEip3(self) -> bool: ...
    def isMaster(self) -> bool: ...
    @staticmethod
    def nextPath(secrets: scala.collection.IndexedSeq['ExtendedSecretKey'], usePreEip3Derivation: bool) -> scala.util.Try['DerivationPath']: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def publicBranch(self) -> bool: ...
    def toPrivateBranch(self) -> 'DerivationPath': ...
    def toPublicBranch(self) -> 'DerivationPath': ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'DerivationPath') -> scala.Option[scala.Tuple2[scala.collection.Seq[typing.Any], typing.Any]]: ...

class DerivationPathSerializer:
    @staticmethod
    def parse(r: scorex.util.serialization.Reader) -> DerivationPath: ...
    @staticmethod
    def parseBytes(bytes: typing.List[int]) -> typing.Any: ...
    @staticmethod
    def parseBytesTry(bytes: typing.List[int]) -> scala.util.Try[DerivationPath]: ...
    @staticmethod
    def parseTry(r: scorex.util.serialization.Reader) -> scala.util.Try[DerivationPath]: ...
    @staticmethod
    def serialize(obj: DerivationPath, w: scorex.util.serialization.Writer) -> None: ...
    @staticmethod
    def toBytes(obj: typing.Any) -> typing.List[int]: ...

class EncryptedSecret(scala.Product, scala.Serializable):
    def __init__(self, cipherText: typing.Union[java.lang.String, str], salt: typing.Union[java.lang.String, str], iv: typing.Union[java.lang.String, str], authTag: typing.Union[java.lang.String, str], cipherParams: org.ergoplatform.wallet.settings.EncryptionSettings): ...
    @typing.overload
    @staticmethod
    def apply(cipherText: typing.List[int], salt: typing.List[int], iv: typing.List[int], authTag: typing.List[int], cipherParams: org.ergoplatform.wallet.settings.EncryptionSettings) -> 'EncryptedSecret': ...
    @typing.overload
    @staticmethod
    def apply(cipherText: typing.Union[java.lang.String, str], salt: typing.Union[java.lang.String, str], iv: typing.Union[java.lang.String, str], authTag: typing.Union[java.lang.String, str], cipherParams: org.ergoplatform.wallet.settings.EncryptionSettings) -> 'EncryptedSecret': ...
    def authTag(self) -> java.lang.String: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def cipherParams(self) -> org.ergoplatform.wallet.settings.EncryptionSettings: ...
    def cipherText(self) -> java.lang.String: ...
    def copy(self, cipherText: typing.Union[java.lang.String, str], salt: typing.Union[java.lang.String, str], iv: typing.Union[java.lang.String, str], authTag: typing.Union[java.lang.String, str], cipherParams: org.ergoplatform.wallet.settings.EncryptionSettings) -> 'EncryptedSecret': ...
    def copy$default$1(self) -> java.lang.String: ...
    def copy$default$2(self) -> java.lang.String: ...
    def copy$default$3(self) -> java.lang.String: ...
    def copy$default$4(self) -> java.lang.String: ...
    def copy$default$5(self) -> org.ergoplatform.wallet.settings.EncryptionSettings: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def iv(self) -> java.lang.String: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def salt(self) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'EncryptedSecret') -> scala.Option[scala.Tuple5[java.lang.String, java.lang.String, java.lang.String, java.lang.String, org.ergoplatform.wallet.settings.EncryptionSettings]]: ...
    class EncryptedSecretDecoder$(io.circe.Decoder['EncryptedSecret']):
        MODULE$: typing.ClassVar['EncryptedSecret.EncryptedSecretDecoder.'] = ...
        def __init__(self): ...
        def accumulating(self, c: io.circe.HCursor) -> cats.data.Validated[cats.data.NonEmptyList[io.circe.DecodingFailure], 'EncryptedSecret']: ...
        def apply(self, cursor: io.circe.HCursor) -> scala.util.Either[io.circe.DecodingFailure, 'EncryptedSecret']: ...
        def at(self, field: typing.Union[java.lang.String, str]) -> io.circe.Decoder['EncryptedSecret']: ...
        def decodeAccumulating(self, c: io.circe.HCursor) -> cats.data.Validated[cats.data.NonEmptyList[io.circe.DecodingFailure], 'EncryptedSecret']: ...
        def decodeJson(self, j: io.circe.Json) -> scala.util.Either[io.circe.DecodingFailure, 'EncryptedSecret']: ...
        _either__B = typing.TypeVar('_either__B')  # <B>
        def either(self, decodeB: io.circe.Decoder[_either__B]) -> io.circe.Decoder[scala.util.Either['EncryptedSecret', _either__B]]: ...
        _emap__B = typing.TypeVar('_emap__B')  # <B>
        def emap(self, f: scala.Function1['EncryptedSecret', scala.util.Either[typing.Union[java.lang.String, str], _emap__B]]) -> io.circe.Decoder[_emap__B]: ...
        _emapTry__B = typing.TypeVar('_emapTry__B')  # <B>
        def emapTry(self, f: scala.Function1['EncryptedSecret', scala.util.Try[_emapTry__B]]) -> io.circe.Decoder[_emapTry__B]: ...
        @typing.overload
        def ensure(self, errors: scala.Function1['EncryptedSecret', scala.collection.immutable.List[typing.Union[java.lang.String, str]]]) -> io.circe.Decoder['EncryptedSecret']: ...
        @typing.overload
        def ensure(self, pred: scala.Function1['EncryptedSecret', typing.Any], message: scala.Function0[typing.Union[java.lang.String, str]]) -> io.circe.Decoder['EncryptedSecret']: ...
        _flatMap__B = typing.TypeVar('_flatMap__B')  # <B>
        def flatMap(self, f: scala.Function1['EncryptedSecret', io.circe.Decoder[_flatMap__B]]) -> io.circe.Decoder[_flatMap__B]: ...
        def handleErrorWith(self, f: scala.Function1[io.circe.DecodingFailure, io.circe.Decoder['EncryptedSecret']]) -> io.circe.Decoder['EncryptedSecret']: ...
        def kleisli(self) -> cats.data.Kleisli[scala.util.Either, io.circe.HCursor, 'EncryptedSecret']: ...
        _map__B = typing.TypeVar('_map__B')  # <B>
        def map(self, f: scala.Function1['EncryptedSecret', _map__B]) -> io.circe.Decoder[_map__B]: ...
        def prepare(self, f: scala.Function1[io.circe.ACursor, io.circe.ACursor]) -> io.circe.Decoder['EncryptedSecret']: ...
        _product__B = typing.TypeVar('_product__B')  # <B>
        def product(self, fb: io.circe.Decoder[_product__B]) -> io.circe.Decoder[scala.Tuple2['EncryptedSecret', _product__B]]: ...
        def tryDecode(self, c: io.circe.ACursor) -> scala.util.Either[io.circe.DecodingFailure, 'EncryptedSecret']: ...
        def tryDecodeAccumulating(self, c: io.circe.ACursor) -> cats.data.Validated[cats.data.NonEmptyList[io.circe.DecodingFailure], 'EncryptedSecret']: ...
        @typing.overload
        def validate(self, errors: scala.Function1[io.circe.HCursor, scala.collection.immutable.List[typing.Union[java.lang.String, str]]]) -> io.circe.Decoder['EncryptedSecret']: ...
        @typing.overload
        def validate(self, pred: scala.Function1[io.circe.HCursor, typing.Any], message: scala.Function0[typing.Union[java.lang.String, str]]) -> io.circe.Decoder['EncryptedSecret']: ...
        def withErrorMessage(self, message: typing.Union[java.lang.String, str]) -> io.circe.Decoder['EncryptedSecret']: ...
    class EncryptedSecretEncoder$(io.circe.Encoder['EncryptedSecret']):
        MODULE$: typing.ClassVar['EncryptedSecret.EncryptedSecretEncoder.'] = ...
        def __init__(self): ...
        def apply(self, secret: 'EncryptedSecret') -> io.circe.Json: ...
        _contramap__B = typing.TypeVar('_contramap__B')  # <B>
        def contramap(self, f: scala.Function1[_contramap__B, 'EncryptedSecret']) -> io.circe.Encoder[_contramap__B]: ...
        def mapJson(self, f: scala.Function1[io.circe.Json, io.circe.Json]) -> io.circe.Encoder['EncryptedSecret']: ...

_ExtendedKey__T = typing.TypeVar('_ExtendedKey__T', bound='ExtendedKey')  # <T>
class ExtendedKey(typing.Generic[_ExtendedKey__T]):
    @staticmethod
    def $init$($this: 'ExtendedKey') -> None: ...
    def chainCode(self) -> typing.List[int]: ...
    def child(self, idx: int) -> _ExtendedKey__T: ...
    def derive(self, upPath: DerivationPath) -> _ExtendedKey__T: ...
    def keyBytes(self) -> typing.List[int]: ...
    def path(self) -> DerivationPath: ...
    def selfReflection(self) -> _ExtendedKey__T: ...

class ExtendedPublicKeySerializer:
    @staticmethod
    def PublicKeyBytesSize() -> int: ...
    @staticmethod
    def parse(r: scorex.util.serialization.Reader) -> 'ExtendedPublicKey': ...
    @staticmethod
    def parseBytes(bytes: typing.List[int]) -> typing.Any: ...
    @staticmethod
    def parseBytesTry(bytes: typing.List[int]) -> scala.util.Try['ExtendedPublicKey']: ...
    @staticmethod
    def parseTry(r: scorex.util.serialization.Reader) -> scala.util.Try['ExtendedPublicKey']: ...
    @staticmethod
    def serialize(obj: 'ExtendedPublicKey', w: scorex.util.serialization.Writer) -> None: ...
    @staticmethod
    def toBytes(obj: typing.Any) -> typing.List[int]: ...

class ExtendedSecretKeySerializer:
    @staticmethod
    def parse(r: scorex.util.serialization.Reader) -> 'ExtendedSecretKey': ...
    @staticmethod
    def parseBytes(bytes: typing.List[int]) -> typing.Any: ...
    @staticmethod
    def parseBytesTry(bytes: typing.List[int]) -> scala.util.Try['ExtendedSecretKey']: ...
    @staticmethod
    def parseTry(r: scorex.util.serialization.Reader) -> scala.util.Try['ExtendedSecretKey']: ...
    @staticmethod
    def serialize(obj: 'ExtendedSecretKey', w: scorex.util.serialization.Writer) -> None: ...
    @staticmethod
    def toBytes(obj: typing.Any) -> typing.List[int]: ...

class Index:
    @staticmethod
    def HardRangeStart() -> int: ...
    @staticmethod
    def hardIndex(i: int) -> int: ...
    @staticmethod
    def isHardened(i: int) -> bool: ...
    @staticmethod
    def parseIndex(xs: typing.List[int]) -> int: ...
    @staticmethod
    def serializeIndex(i: int) -> typing.List[int]: ...

class SecretKey:
    def privateInput(self) -> sigmastate.basics.SigmaProtocolPrivateInput[typing.Any, typing.Any]: ...

class SecretStorage:
    def checkSeed(self, mnemonic: org.ergoplatform.wallet.interface4j.SecretString, mnemonicPassOpt: scala.Option[org.ergoplatform.wallet.interface4j.SecretString]) -> bool: ...
    def isLocked(self) -> bool: ...
    def lock(self) -> None: ...
    def secret(self) -> scala.Option['ExtendedSecretKey']: ...
    def secretFile(self) -> java.io.File: ...
    def unlock(self, pass_: org.ergoplatform.wallet.interface4j.SecretString) -> scala.util.Try[scala.runtime.BoxedUnit]: ...

class ExtendedPublicKey(ExtendedKey['ExtendedPublicKey']):
    def __init__(self, keyBytes: typing.List[int], chainCode: typing.List[int], path: DerivationPath): ...
    def chainCode(self) -> typing.List[int]: ...
    def child(self, idx: int) -> 'ExtendedPublicKey': ...
    def derive(self, upPath: DerivationPath) -> ExtendedKey: ...
    @staticmethod
    def deriveChildPublicKey(parentKey: 'ExtendedPublicKey', idx: int) -> 'ExtendedPublicKey': ...
    def equals(self, obj: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def key(self) -> sigmastate.basics.DLogProtocol.ProveDlog: ...
    def keyBytes(self) -> typing.List[int]: ...
    def path(self) -> DerivationPath: ...
    def selfReflection(self) -> 'ExtendedPublicKey': ...
    def toString(self) -> java.lang.String: ...

class ExtendedSecretKey(ExtendedKey['ExtendedSecretKey'], SecretKey):
    def __init__(self, keyBytes: typing.List[int], chainCode: typing.List[int], path: DerivationPath): ...
    def chainCode(self) -> typing.List[int]: ...
    def child(self, idx: int) -> 'ExtendedSecretKey': ...
    def derive(self, upPath: DerivationPath) -> ExtendedKey: ...
    @staticmethod
    def deriveChildPublicKey(parentKey: 'ExtendedSecretKey', idx: int) -> ExtendedPublicKey: ...
    @staticmethod
    def deriveChildSecretKey(parentKey: 'ExtendedSecretKey', idx: int) -> 'ExtendedSecretKey': ...
    @staticmethod
    def deriveMasterKey(seed: typing.List[int]) -> 'ExtendedSecretKey': ...
    def equals(self, obj: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def isErased(self) -> bool: ...
    def keyBytes(self) -> typing.List[int]: ...
    def path(self) -> DerivationPath: ...
    def privateInput(self) -> sigmastate.basics.DLogProtocol.DLogProverInput: ...
    def publicImage(self) -> sigmastate.basics.DLogProtocol.ProveDlog: ...
    def publicKey(self) -> ExtendedPublicKey: ...
    def selfReflection(self) -> 'ExtendedSecretKey': ...
    def zeroSecret(self) -> None: ...

class JsonSecretStorage(SecretStorage):
    def __init__(self, secretFile: typing.Union[java.io.File, jpype.protocol.SupportsPath], encryptionSettings: org.ergoplatform.wallet.settings.EncryptionSettings): ...
    def checkSeed(self, mnemonic: org.ergoplatform.wallet.interface4j.SecretString, mnemonicPassOpt: scala.Option[org.ergoplatform.wallet.interface4j.SecretString]) -> bool: ...
    @staticmethod
    def init(seed: typing.List[int], pass_: org.ergoplatform.wallet.interface4j.SecretString, settings: org.ergoplatform.wallet.settings.SecretStorageSettings) -> 'JsonSecretStorage': ...
    def isLocked(self) -> bool: ...
    def lock(self) -> None: ...
    @staticmethod
    def readFile(settings: org.ergoplatform.wallet.settings.SecretStorageSettings) -> scala.util.Try['JsonSecretStorage']: ...
    @staticmethod
    def restore(mnemonic: org.ergoplatform.wallet.interface4j.SecretString, mnemonicPassOpt: scala.Option[org.ergoplatform.wallet.interface4j.SecretString], encryptionPass: org.ergoplatform.wallet.interface4j.SecretString, settings: org.ergoplatform.wallet.settings.SecretStorageSettings) -> 'JsonSecretStorage': ...
    def secret(self) -> scala.Option[ExtendedSecretKey]: ...
    def secretFile(self) -> java.io.File: ...
    def unlock(self, pass_: org.ergoplatform.wallet.interface4j.SecretString) -> scala.util.Try[scala.runtime.BoxedUnit]: ...

class PrimitiveSecretKey(SecretKey):
    @staticmethod
    def apply(sigmaPrivateInput: sigmastate.basics.SigmaProtocolPrivateInput[typing.Any, typing.Any]) -> 'PrimitiveSecretKey': ...

class DhtSecretKey(PrimitiveSecretKey, scala.Product, scala.Serializable):
    def __init__(self, privateInput: sigmastate.basics.DiffieHellmanTupleProverInput): ...
    _andThen__A = typing.TypeVar('_andThen__A')  # <A>
    @staticmethod
    def andThen(g: scala.Function1['DhtSecretKey', _andThen__A]) -> scala.Function1[sigmastate.basics.DiffieHellmanTupleProverInput, _andThen__A]: ...
    @staticmethod
    def apply(privateInput: sigmastate.basics.DiffieHellmanTupleProverInput) -> 'DhtSecretKey': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    _compose__A = typing.TypeVar('_compose__A')  # <A>
    @staticmethod
    def compose(g: scala.Function1[_compose__A, sigmastate.basics.DiffieHellmanTupleProverInput]) -> scala.Function1[_compose__A, 'DhtSecretKey']: ...
    def copy(self, privateInput: sigmastate.basics.DiffieHellmanTupleProverInput) -> 'DhtSecretKey': ...
    def copy$default$1(self) -> sigmastate.basics.DiffieHellmanTupleProverInput: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def privateInput(self) -> sigmastate.basics.DiffieHellmanTupleProverInput: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'DhtSecretKey') -> scala.Option[sigmastate.basics.DiffieHellmanTupleProverInput]: ...

class DlogSecretKey(PrimitiveSecretKey, scala.Product, scala.Serializable):
    def __init__(self, privateInput: sigmastate.basics.DLogProtocol.DLogProverInput): ...
    _andThen__A = typing.TypeVar('_andThen__A')  # <A>
    @staticmethod
    def andThen(g: scala.Function1['DlogSecretKey', _andThen__A]) -> scala.Function1[sigmastate.basics.DLogProtocol.DLogProverInput, _andThen__A]: ...
    @staticmethod
    def apply(privateInput: sigmastate.basics.DLogProtocol.DLogProverInput) -> 'DlogSecretKey': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    _compose__A = typing.TypeVar('_compose__A')  # <A>
    @staticmethod
    def compose(g: scala.Function1[_compose__A, sigmastate.basics.DLogProtocol.DLogProverInput]) -> scala.Function1[_compose__A, 'DlogSecretKey']: ...
    def copy(self, privateInput: sigmastate.basics.DLogProtocol.DLogProverInput) -> 'DlogSecretKey': ...
    def copy$default$1(self) -> sigmastate.basics.DLogProtocol.DLogProverInput: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def privateInput(self) -> sigmastate.basics.DLogProtocol.DLogProverInput: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'DlogSecretKey') -> scala.Option[sigmastate.basics.DLogProtocol.DLogProverInput]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.secrets")``.

    DerivationPath: typing.Type[DerivationPath]
    DerivationPathSerializer: typing.Type[DerivationPathSerializer]
    DhtSecretKey: typing.Type[DhtSecretKey]
    DlogSecretKey: typing.Type[DlogSecretKey]
    EncryptedSecret: typing.Type[EncryptedSecret]
    ExtendedKey: typing.Type[ExtendedKey]
    ExtendedPublicKey: typing.Type[ExtendedPublicKey]
    ExtendedPublicKeySerializer: typing.Type[ExtendedPublicKeySerializer]
    ExtendedSecretKey: typing.Type[ExtendedSecretKey]
    ExtendedSecretKeySerializer: typing.Type[ExtendedSecretKeySerializer]
    Index: typing.Type[Index]
    JsonSecretStorage: typing.Type[JsonSecretStorage]
    PrimitiveSecretKey: typing.Type[PrimitiveSecretKey]
    SecretKey: typing.Type[SecretKey]
    SecretStorage: typing.Type[SecretStorage]



import java.net
import typing



class URLStreamHandlerProvider(java.net.URLStreamHandlerFactory): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.net.spi")``.

    URLStreamHandlerProvider: typing.Type[URLStreamHandlerProvider]



import scorex.crypto.authds.avltree.batch
import typing



class package:
    @staticmethod
    def LabelOfNone() -> typing.List[int]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scorex.crypto.authds.avltree")``.

    package: typing.Type[package]
    batch: scorex.crypto.authds.avltree.batch.__module_protocol__



import datetime
import java.io
import java.lang
import java.security
import java.time
import java.util
import java.util.function
import typing



class ErrorManager:
    GENERIC_FAILURE: typing.ClassVar[int] = ...
    WRITE_FAILURE: typing.ClassVar[int] = ...
    FLUSH_FAILURE: typing.ClassVar[int] = ...
    CLOSE_FAILURE: typing.ClassVar[int] = ...
    OPEN_FAILURE: typing.ClassVar[int] = ...
    FORMAT_FAILURE: typing.ClassVar[int] = ...
    def __init__(self): ...
    def error(self, string: str, exception: java.lang.Exception, int: int) -> None: ...

class Filter:
    def isLoggable(self, logRecord: 'LogRecord') -> bool: ...

class Formatter:
    def format(self, logRecord: 'LogRecord') -> str: ...
    def formatMessage(self, logRecord: 'LogRecord') -> str: ...
    def getHead(self, handler: 'Handler') -> str: ...
    def getTail(self, handler: 'Handler') -> str: ...

class Handler:
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def getEncoding(self) -> str: ...
    def getErrorManager(self) -> ErrorManager: ...
    def getFilter(self) -> Filter: ...
    def getFormatter(self) -> Formatter: ...
    def getLevel(self) -> 'Level': ...
    def isLoggable(self, logRecord: 'LogRecord') -> bool: ...
    def publish(self, logRecord: 'LogRecord') -> None: ...
    def setEncoding(self, string: str) -> None: ...
    def setErrorManager(self, errorManager: ErrorManager) -> None: ...
    def setFilter(self, filter: typing.Union[Filter, typing.Callable]) -> None: ...
    def setFormatter(self, formatter: Formatter) -> None: ...
    def setLevel(self, level: 'Level') -> None: ...

class Level(java.io.Serializable):
    OFF: typing.ClassVar['Level'] = ...
    SEVERE: typing.ClassVar['Level'] = ...
    WARNING: typing.ClassVar['Level'] = ...
    INFO: typing.ClassVar['Level'] = ...
    CONFIG: typing.ClassVar['Level'] = ...
    FINE: typing.ClassVar['Level'] = ...
    FINER: typing.ClassVar['Level'] = ...
    FINEST: typing.ClassVar['Level'] = ...
    ALL: typing.ClassVar['Level'] = ...
    def equals(self, object: typing.Any) -> bool: ...
    def getLocalizedName(self) -> str: ...
    def getName(self) -> str: ...
    def getResourceBundleName(self) -> str: ...
    def hashCode(self) -> int: ...
    def intValue(self) -> int: ...
    @staticmethod
    def parse(string: str) -> 'Level': ...
    def toString(self) -> str: ...

class LogManager:
    LOGGING_MXBEAN_NAME: typing.ClassVar[str] = ...
    def addConfigurationListener(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> 'LogManager': ...
    def addLogger(self, logger: 'Logger') -> bool: ...
    def checkAccess(self) -> None: ...
    @staticmethod
    def getLogManager() -> 'LogManager': ...
    def getLogger(self, string: str) -> 'Logger': ...
    def getLoggerNames(self) -> java.util.Enumeration[str]: ...
    @staticmethod
    def getLoggingMXBean() -> 'LoggingMXBean': ...
    def getProperty(self, string: str) -> str: ...
    @typing.overload
    def readConfiguration(self) -> None: ...
    @typing.overload
    def readConfiguration(self, inputStream: java.io.InputStream) -> None: ...
    def removeConfigurationListener(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> None: ...
    def reset(self) -> None: ...
    @typing.overload
    def updateConfiguration(self, inputStream: java.io.InputStream, function: typing.Union[java.util.function.Function[str, typing.Union[java.util.function.BiFunction[str, str, str], typing.Callable[[str, str], str]]], typing.Callable[[str], typing.Union[java.util.function.BiFunction[str, str, str], typing.Callable[[str, str], str]]]]) -> None: ...
    @typing.overload
    def updateConfiguration(self, function: typing.Union[java.util.function.Function[str, typing.Union[java.util.function.BiFunction[str, str, str], typing.Callable[[str, str], str]]], typing.Callable[[str], typing.Union[java.util.function.BiFunction[str, str, str], typing.Callable[[str, str], str]]]]) -> None: ...

class LogRecord(java.io.Serializable):
    def __init__(self, level: Level, string: str): ...
    def getInstant(self) -> java.time.Instant: ...
    def getLevel(self) -> Level: ...
    def getLoggerName(self) -> str: ...
    def getMessage(self) -> str: ...
    def getMillis(self) -> int: ...
    def getParameters(self) -> typing.List[typing.Any]: ...
    def getResourceBundle(self) -> java.util.ResourceBundle: ...
    def getResourceBundleName(self) -> str: ...
    def getSequenceNumber(self) -> int: ...
    def getSourceClassName(self) -> str: ...
    def getSourceMethodName(self) -> str: ...
    def getThreadID(self) -> int: ...
    def getThrown(self) -> java.lang.Throwable: ...
    def setInstant(self, instant: typing.Union[java.time.Instant, datetime.datetime]) -> None: ...
    def setLevel(self, level: Level) -> None: ...
    def setLoggerName(self, string: str) -> None: ...
    def setMessage(self, string: str) -> None: ...
    def setMillis(self, long: int) -> None: ...
    def setParameters(self, objectArray: typing.List[typing.Any]) -> None: ...
    def setResourceBundle(self, resourceBundle: java.util.ResourceBundle) -> None: ...
    def setResourceBundleName(self, string: str) -> None: ...
    def setSequenceNumber(self, long: int) -> None: ...
    def setSourceClassName(self, string: str) -> None: ...
    def setSourceMethodName(self, string: str) -> None: ...
    def setThreadID(self, int: int) -> None: ...
    def setThrown(self, throwable: java.lang.Throwable) -> None: ...

class Logger:
    GLOBAL_LOGGER_NAME: typing.ClassVar[str] = ...
    global_: typing.ClassVar['Logger'] = ...
    def addHandler(self, handler: Handler) -> None: ...
    @typing.overload
    def config(self, string: str) -> None: ...
    @typing.overload
    def config(self, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    @typing.overload
    def entering(self, string: str, string2: str) -> None: ...
    @typing.overload
    def entering(self, string: str, string2: str, object: typing.Any) -> None: ...
    @typing.overload
    def entering(self, string: str, string2: str, objectArray: typing.List[typing.Any]) -> None: ...
    @typing.overload
    def exiting(self, string: str, string2: str) -> None: ...
    @typing.overload
    def exiting(self, string: str, string2: str, object: typing.Any) -> None: ...
    @typing.overload
    def fine(self, string: str) -> None: ...
    @typing.overload
    def fine(self, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    @typing.overload
    def finer(self, string: str) -> None: ...
    @typing.overload
    def finer(self, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    @typing.overload
    def finest(self, string: str) -> None: ...
    @typing.overload
    def finest(self, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    @typing.overload
    @staticmethod
    def getAnonymousLogger() -> 'Logger': ...
    @typing.overload
    @staticmethod
    def getAnonymousLogger(string: str) -> 'Logger': ...
    def getFilter(self) -> Filter: ...
    @staticmethod
    def getGlobal() -> 'Logger': ...
    def getHandlers(self) -> typing.List[Handler]: ...
    def getLevel(self) -> Level: ...
    @typing.overload
    @staticmethod
    def getLogger(string: str) -> 'Logger': ...
    @typing.overload
    @staticmethod
    def getLogger(string: str, string2: str) -> 'Logger': ...
    def getName(self) -> str: ...
    def getParent(self) -> 'Logger': ...
    def getResourceBundle(self) -> java.util.ResourceBundle: ...
    def getResourceBundleName(self) -> str: ...
    def getUseParentHandlers(self) -> bool: ...
    @typing.overload
    def info(self, string: str) -> None: ...
    @typing.overload
    def info(self, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    def isLoggable(self, level: Level) -> bool: ...
    @typing.overload
    def log(self, level: Level, string: str) -> None: ...
    @typing.overload
    def log(self, level: Level, string: str, object: typing.Any) -> None: ...
    @typing.overload
    def log(self, level: Level, string: str, objectArray: typing.List[typing.Any]) -> None: ...
    @typing.overload
    def log(self, level: Level, string: str, throwable: java.lang.Throwable) -> None: ...
    @typing.overload
    def log(self, level: Level, throwable: java.lang.Throwable, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    @typing.overload
    def log(self, level: Level, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    @typing.overload
    def log(self, logRecord: LogRecord) -> None: ...
    @typing.overload
    def logp(self, level: Level, string: str, string2: str, string3: str) -> None: ...
    @typing.overload
    def logp(self, level: Level, string: str, string2: str, string3: str, object: typing.Any) -> None: ...
    @typing.overload
    def logp(self, level: Level, string: str, string2: str, string3: str, objectArray: typing.List[typing.Any]) -> None: ...
    @typing.overload
    def logp(self, level: Level, string: str, string2: str, string3: str, throwable: java.lang.Throwable) -> None: ...
    @typing.overload
    def logp(self, level: Level, string: str, string2: str, throwable: java.lang.Throwable, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    @typing.overload
    def logp(self, level: Level, string: str, string2: str, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    @typing.overload
    def logrb(self, level: Level, string: str, string2: str, string3: str, string4: str) -> None: ...
    @typing.overload
    def logrb(self, level: Level, string: str, string2: str, string3: str, string4: str, object: typing.Any) -> None: ...
    @typing.overload
    def logrb(self, level: Level, string: str, string2: str, string3: str, string4: str, objectArray: typing.List[typing.Any]) -> None: ...
    @typing.overload
    def logrb(self, level: Level, string: str, string2: str, string3: str, string4: str, throwable: java.lang.Throwable) -> None: ...
    @typing.overload
    def logrb(self, level: Level, string: str, string2: str, resourceBundle: java.util.ResourceBundle, string3: str, objectArray: typing.List[typing.Any]) -> None: ...
    @typing.overload
    def logrb(self, level: Level, string: str, string2: str, resourceBundle: java.util.ResourceBundle, string3: str, throwable: java.lang.Throwable) -> None: ...
    @typing.overload
    def logrb(self, level: Level, resourceBundle: java.util.ResourceBundle, string: str, objectArray: typing.List[typing.Any]) -> None: ...
    @typing.overload
    def logrb(self, level: Level, resourceBundle: java.util.ResourceBundle, string: str, throwable: java.lang.Throwable) -> None: ...
    def removeHandler(self, handler: Handler) -> None: ...
    def setFilter(self, filter: typing.Union[Filter, typing.Callable]) -> None: ...
    def setLevel(self, level: Level) -> None: ...
    def setParent(self, logger: 'Logger') -> None: ...
    def setResourceBundle(self, resourceBundle: java.util.ResourceBundle) -> None: ...
    def setUseParentHandlers(self, boolean: bool) -> None: ...
    @typing.overload
    def severe(self, string: str) -> None: ...
    @typing.overload
    def severe(self, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...
    def throwing(self, string: str, string2: str, throwable: java.lang.Throwable) -> None: ...
    @typing.overload
    def warning(self, string: str) -> None: ...
    @typing.overload
    def warning(self, supplier: typing.Union[java.util.function.Supplier[str], typing.Callable[[], str]]) -> None: ...

class LoggingMXBean:
    def getLoggerLevel(self, string: str) -> str: ...
    def getLoggerNames(self) -> java.util.List[str]: ...
    def getParentLoggerName(self, string: str) -> str: ...
    def setLoggerLevel(self, string: str, string2: str) -> None: ...

class LoggingPermission(java.security.BasicPermission):
    def __init__(self, string: str, string2: str): ...

class MemoryHandler(Handler):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, handler: Handler, int: int, level: Level): ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def getPushLevel(self) -> Level: ...
    def isLoggable(self, logRecord: LogRecord) -> bool: ...
    def publish(self, logRecord: LogRecord) -> None: ...
    def push(self) -> None: ...
    def setPushLevel(self, level: Level) -> None: ...

class SimpleFormatter(Formatter):
    def __init__(self): ...
    def format(self, logRecord: LogRecord) -> str: ...

class StreamHandler(Handler):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, formatter: Formatter): ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def isLoggable(self, logRecord: LogRecord) -> bool: ...
    def publish(self, logRecord: LogRecord) -> None: ...
    def setEncoding(self, string: str) -> None: ...

class XMLFormatter(Formatter):
    def __init__(self): ...
    def format(self, logRecord: LogRecord) -> str: ...
    def getHead(self, handler: Handler) -> str: ...
    def getTail(self, handler: Handler) -> str: ...

class ConsoleHandler(StreamHandler):
    def __init__(self): ...
    def close(self) -> None: ...
    def publish(self, logRecord: LogRecord) -> None: ...

class FileHandler(StreamHandler):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, boolean: bool): ...
    @typing.overload
    def __init__(self, string: str, int: int, int2: int): ...
    @typing.overload
    def __init__(self, string: str, int: int, int2: int, boolean: bool): ...
    @typing.overload
    def __init__(self, string: str, long: int, int: int, boolean: bool): ...
    def close(self) -> None: ...
    def publish(self, logRecord: LogRecord) -> None: ...

class SocketHandler(StreamHandler):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str, int: int): ...
    def close(self) -> None: ...
    def publish(self, logRecord: LogRecord) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.util.logging")``.

    ConsoleHandler: typing.Type[ConsoleHandler]
    ErrorManager: typing.Type[ErrorManager]
    FileHandler: typing.Type[FileHandler]
    Filter: typing.Type[Filter]
    Formatter: typing.Type[Formatter]
    Handler: typing.Type[Handler]
    Level: typing.Type[Level]
    LogManager: typing.Type[LogManager]
    LogRecord: typing.Type[LogRecord]
    Logger: typing.Type[Logger]
    LoggingMXBean: typing.Type[LoggingMXBean]
    LoggingPermission: typing.Type[LoggingPermission]
    MemoryHandler: typing.Type[MemoryHandler]
    SimpleFormatter: typing.Type[SimpleFormatter]
    SocketHandler: typing.Type[SocketHandler]
    StreamHandler: typing.Type[StreamHandler]
    XMLFormatter: typing.Type[XMLFormatter]



import java.lang.annotation
import typing



class EverythingIsNonNull(java.lang.annotation.Annotation):
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("retrofit2.internal")``.

    EverythingIsNonNull: typing.Type[EverythingIsNonNull]



import java.io
import java.lang
import java.net
import java.nio.charset
import jpype.protocol
import scala
import scala.collection
import scala.collection.generic
import scala.collection.immutable
import scala.collection.mutable
import scala.math
import scala.reflect
import scala.runtime
import typing



class AnsiColor:
    @staticmethod
    def $init$($this: 'AnsiColor') -> None: ...
    def BLACK(self) -> java.lang.String: ...
    def BLACK_B(self) -> java.lang.String: ...
    def BLINK(self) -> java.lang.String: ...
    def BLUE(self) -> java.lang.String: ...
    def BLUE_B(self) -> java.lang.String: ...
    def BOLD(self) -> java.lang.String: ...
    def CYAN(self) -> java.lang.String: ...
    def CYAN_B(self) -> java.lang.String: ...
    def GREEN(self) -> java.lang.String: ...
    def GREEN_B(self) -> java.lang.String: ...
    def INVISIBLE(self) -> java.lang.String: ...
    def MAGENTA(self) -> java.lang.String: ...
    def MAGENTA_B(self) -> java.lang.String: ...
    def RED(self) -> java.lang.String: ...
    def RED_B(self) -> java.lang.String: ...
    def RESET(self) -> java.lang.String: ...
    def REVERSED(self) -> java.lang.String: ...
    def UNDERLINED(self) -> java.lang.String: ...
    def WHITE(self) -> java.lang.String: ...
    def WHITE_B(self) -> java.lang.String: ...
    def YELLOW(self) -> java.lang.String: ...
    def YELLOW_B(self) -> java.lang.String: ...

class Codec:
    def __init__(self, charSet: java.nio.charset.Charset): ...
    @staticmethod
    def ISO8859() -> 'Codec': ...
    @staticmethod
    def UTF8() -> 'Codec': ...
    @typing.overload
    @staticmethod
    def apply(encoding: typing.Union[java.lang.String, str]) -> 'Codec': ...
    @typing.overload
    @staticmethod
    def apply(charSet: java.nio.charset.Charset) -> 'Codec': ...
    @typing.overload
    @staticmethod
    def apply(decoder: java.nio.charset.CharsetDecoder) -> 'Codec': ...
    def charSet(self) -> java.nio.charset.Charset: ...
    @staticmethod
    def charset2codec(c: java.nio.charset.Charset) -> 'Codec': ...
    def decoder(self) -> java.nio.charset.CharsetDecoder: ...
    @staticmethod
    def decoder2codec(cd: java.nio.charset.CharsetDecoder) -> 'Codec': ...
    def decodingReplaceWith(self, newReplacement: typing.Union[java.lang.String, str]) -> 'Codec': ...
    @staticmethod
    def default() -> 'Codec': ...
    @staticmethod
    def defaultCharsetCodec() -> 'Codec': ...
    def encoder(self) -> java.nio.charset.CharsetEncoder: ...
    def encodingReplaceWith(self, newReplacement: typing.List[int]) -> 'Codec': ...
    @staticmethod
    def fallbackSystemCodec() -> 'Codec': ...
    @staticmethod
    def fileEncodingCodec() -> 'Codec': ...
    @typing.overload
    @staticmethod
    def fromUTF8(bytes: typing.List[int]) -> typing.List[str]: ...
    @typing.overload
    @staticmethod
    def fromUTF8(bytes: typing.List[int], offset: int, len: int) -> typing.List[str]: ...
    def name(self) -> java.lang.String: ...
    def onCodingException(self, handler: scala.Function1[java.nio.charset.CharacterCodingException, typing.Any]) -> 'Codec': ...
    def onMalformedInput(self, newAction: java.nio.charset.CodingErrorAction) -> 'Codec': ...
    def onUnmappableCharacter(self, newAction: java.nio.charset.CodingErrorAction) -> 'Codec': ...
    @staticmethod
    def string2codec(s: typing.Union[java.lang.String, str]) -> 'Codec': ...
    def toString(self) -> java.lang.String: ...
    @typing.overload
    @staticmethod
    def toUTF8(chars: typing.List[str], offset: int, len: int) -> typing.List[int]: ...
    @typing.overload
    @staticmethod
    def toUTF8(cs: typing.Union[java.lang.CharSequence, str]) -> typing.List[int]: ...
    def wrap(self, body: scala.Function0[typing.Any]) -> int: ...

class LowPriorityCodecImplicits:
    @staticmethod
    def $init$($this: 'LowPriorityCodecImplicits') -> None: ...
    def fallbackSystemCodec(self) -> Codec: ...

class Position:
    def __init__(self): ...
    def COLUMN_BITS(self) -> int: ...
    def COLUMN_MASK(self) -> int: ...
    def LINE_BITS(self) -> int: ...
    def LINE_MASK(self) -> int: ...
    def checkInput(self, line: int, column: int) -> None: ...
    def column(self, pos: int) -> int: ...
    def encode(self, line: int, column: int) -> int: ...
    def line(self, pos: int) -> int: ...
    @typing.overload
    def toString(self) -> java.lang.String: ...
    @typing.overload
    def toString(self, pos: int) -> java.lang.String: ...

class StdIn:
    @staticmethod
    def $init$($this: 'StdIn') -> None: ...
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readDouble(self) -> float: ...
    def readFloat(self) -> float: ...
    def readInt(self) -> int: ...
    @typing.overload
    def readLine(self) -> java.lang.String: ...
    @typing.overload
    def readLine(self, text: typing.Union[java.lang.String, str], args: scala.collection.Seq[typing.Any]) -> java.lang.String: ...
    def readLong(self) -> int: ...
    def readShort(self) -> int: ...
    def readf(self, format: typing.Union[java.lang.String, str]) -> scala.collection.immutable.List[typing.Any]: ...
    def readf1(self, format: typing.Union[java.lang.String, str]) -> typing.Any: ...
    def readf2(self, format: typing.Union[java.lang.String, str]) -> scala.Tuple2[typing.Any, typing.Any]: ...
    def readf3(self, format: typing.Union[java.lang.String, str]) -> scala.Tuple3[typing.Any, typing.Any, typing.Any]: ...

class BufferedSource(scala.io.Source):
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, bufferSize: int, codec: Codec): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, codec: Codec): ...
    def bufferedReader(self) -> java.io.BufferedReader: ...
    def codec(self) -> Codec: ...
    def getLines(self) -> scala.collection.Iterator[java.lang.String]: ...
    def iter(self) -> scala.collection.Iterator[typing.Any]: ...
    @typing.overload
    def mkString(self) -> java.lang.String: ...
    @typing.overload
    def mkString(self, sep: typing.Union[java.lang.String, str]) -> java.lang.String: ...
    @typing.overload
    def mkString(self, start: typing.Union[java.lang.String, str], sep: typing.Union[java.lang.String, str], end: typing.Union[java.lang.String, str]) -> java.lang.String: ...
    def reader(self) -> java.io.InputStreamReader: ...
    def scala$io$BufferedSource$$decachedReader(self) -> java.io.BufferedReader: ...
    class BufferedLineIterator(scala.collection.AbstractIterator[java.lang.String]):
        $outer: 'BufferedSource' = ...
        def __init__(self, $outer: 'BufferedSource'): ...
        def hasNext(self) -> bool: ...
        def next(self) -> java.lang.String: ...
        def nextLine(self) -> java.lang.String: ...
        def nextLine_$eq(self, x$1: typing.Union[java.lang.String, str]) -> None: ...

class Source(scala.collection.Iterator[typing.Any], java.io.Closeable):
    def __init__(self): ...
    _$colon$bslash__B = typing.TypeVar('_$colon$bslash__B')  # <B>
    def $colon$bslash(self, z: _.colon.bslash__B, op: scala.Function2[typing.Any, _.colon.bslash__B, _.colon.bslash__B]) -> _.colon.bslash__B: ...
    _$div$colon__B = typing.TypeVar('_$div$colon__B')  # <B>
    def $div$colon(self, z: _.div.colon__B, op: scala.Function2[_.div.colon__B, typing.Any, _.div.colon__B]) -> _.div.colon__B: ...
    _$plus$plus__B = typing.TypeVar('_$plus$plus__B')  # <B>
    def $plus$plus(self, that: scala.Function0[scala.collection.GenTraversableOnce[_.plus.plus__B]]) -> scala.collection.Iterator[_.plus.plus__B]: ...
    @staticmethod
    def DefaultBufSize() -> int: ...
    def NoPositioner(self) -> 'Source.NoPositioner.': ...
    def RelaxedPosition(self) -> 'Source.RelaxedPosition.': ...
    def RelaxedPositioner(self) -> 'Source.RelaxedPositioner.': ...
    @typing.overload
    def addString(self, b: scala.collection.mutable.StringBuilder) -> scala.collection.mutable.StringBuilder: ...
    @typing.overload
    def addString(self, b: scala.collection.mutable.StringBuilder, sep: typing.Union[java.lang.String, str]) -> scala.collection.mutable.StringBuilder: ...
    @typing.overload
    def addString(self, b: scala.collection.mutable.StringBuilder, start: typing.Union[java.lang.String, str], sep: typing.Union[java.lang.String, str], end: typing.Union[java.lang.String, str]) -> scala.collection.mutable.StringBuilder: ...
    _aggregate__B = typing.TypeVar('_aggregate__B')  # <B>
    def aggregate(self, z: scala.Function0[_aggregate__B], seqop: scala.Function2[_aggregate__B, typing.Any, _aggregate__B], combop: scala.Function2[_aggregate__B, _aggregate__B, _aggregate__B]) -> _aggregate__B: ...
    def buffered(self) -> scala.collection.BufferedIterator[typing.Any]: ...
    def ch(self) -> str: ...
    def close(self) -> None: ...
    _collect__B = typing.TypeVar('_collect__B')  # <B>
    def collect(self, pf: scala.PartialFunction[typing.Any, _collect__B]) -> scala.collection.Iterator[_collect__B]: ...
    _collectFirst__B = typing.TypeVar('_collectFirst__B')  # <B>
    def collectFirst(self, pf: scala.PartialFunction[typing.Any, _collectFirst__B]) -> scala.Option[_collectFirst__B]: ...
    def contains(self, elem: typing.Any) -> bool: ...
    _copyToArray_0__B = typing.TypeVar('_copyToArray_0__B')  # <B>
    _copyToArray_1__B = typing.TypeVar('_copyToArray_1__B')  # <B>
    _copyToArray_2__B = typing.TypeVar('_copyToArray_2__B')  # <B>
    @typing.overload
    def copyToArray(self, xs: typing.Any) -> None: ...
    @typing.overload
    def copyToArray(self, xs: typing.Any, start: int) -> None: ...
    @typing.overload
    def copyToArray(self, xs: typing.Any, start: int, len: int) -> None: ...
    _copyToBuffer__B = typing.TypeVar('_copyToBuffer__B')  # <B>
    def copyToBuffer(self, dest: scala.collection.mutable.Buffer[_copyToBuffer__B]) -> None: ...
    _corresponds__B = typing.TypeVar('_corresponds__B')  # <B>
    def corresponds(self, that: scala.collection.GenTraversableOnce[_corresponds__B], p: scala.Function2[typing.Any, _corresponds__B, typing.Any]) -> bool: ...
    def count(self, p: scala.Function1[typing.Any, typing.Any]) -> int: ...
    @staticmethod
    def createBufferedSource(inputStream: java.io.InputStream, bufferSize: int, reset: scala.Function0['Source'], close: scala.Function0[scala.runtime.BoxedUnit], codec: Codec) -> BufferedSource: ...
    @staticmethod
    def createBufferedSource$default$2() -> int: ...
    @staticmethod
    def createBufferedSource$default$3() -> scala.Function0['Source']: ...
    @staticmethod
    def createBufferedSource$default$4() -> scala.Function0[scala.runtime.BoxedUnit]: ...
    def descr(self) -> java.lang.String: ...
    def descr_$eq(self, x$1: typing.Union[java.lang.String, str]) -> None: ...
    def drop(self, n: int) -> scala.collection.Iterator[typing.Any]: ...
    def dropWhile(self, p: scala.Function1[typing.Any, typing.Any]) -> scala.collection.Iterator[typing.Any]: ...
    def duplicate(self) -> scala.Tuple2[scala.collection.Iterator[typing.Any], scala.collection.Iterator[typing.Any]]: ...
    def exists(self, p: scala.Function1[typing.Any, typing.Any]) -> bool: ...
    def filter(self, p: scala.Function1[typing.Any, typing.Any]) -> scala.collection.Iterator[typing.Any]: ...
    def filterNot(self, p: scala.Function1[typing.Any, typing.Any]) -> scala.collection.Iterator[typing.Any]: ...
    def find(self, p: scala.Function1[typing.Any, typing.Any]) -> scala.Option[typing.Any]: ...
    _flatMap__B = typing.TypeVar('_flatMap__B')  # <B>
    def flatMap(self, f: scala.Function1[typing.Any, scala.collection.GenTraversableOnce[_flatMap__B]]) -> scala.collection.Iterator[_flatMap__B]: ...
    _fold__A1 = typing.TypeVar('_fold__A1')  # <A1>
    def fold(self, z: _fold__A1, op: scala.Function2[_fold__A1, _fold__A1, _fold__A1]) -> _fold__A1: ...
    _foldLeft__B = typing.TypeVar('_foldLeft__B')  # <B>
    def foldLeft(self, z: _foldLeft__B, op: scala.Function2[_foldLeft__B, typing.Any, _foldLeft__B]) -> _foldLeft__B: ...
    _foldRight__B = typing.TypeVar('_foldRight__B')  # <B>
    def foldRight(self, z: _foldRight__B, op: scala.Function2[typing.Any, _foldRight__B, _foldRight__B]) -> _foldRight__B: ...
    def forall(self, p: scala.Function1[typing.Any, typing.Any]) -> bool: ...
    _foreach__U = typing.TypeVar('_foreach__U')  # <U>
    def foreach(self, f: scala.Function1[typing.Any, _foreach__U]) -> None: ...
    @typing.overload
    @staticmethod
    def fromBytes(bytes: typing.List[int], enc: typing.Union[java.lang.String, str]) -> 'Source': ...
    @typing.overload
    @staticmethod
    def fromBytes(bytes: typing.List[int], codec: Codec) -> 'Source': ...
    @staticmethod
    def fromChar(c: str) -> 'Source': ...
    @staticmethod
    def fromChars(chars: typing.List[str]) -> 'Source': ...
    @typing.overload
    @staticmethod
    def fromFile(file: typing.Union[java.io.File, jpype.protocol.SupportsPath], bufferSize: int, codec: Codec) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromFile(file: typing.Union[java.io.File, jpype.protocol.SupportsPath], enc: typing.Union[java.lang.String, str]) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromFile(file: typing.Union[java.io.File, jpype.protocol.SupportsPath], enc: typing.Union[java.lang.String, str], bufferSize: int) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromFile(file: typing.Union[java.io.File, jpype.protocol.SupportsPath], codec: Codec) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromFile(name: typing.Union[java.lang.String, str], enc: typing.Union[java.lang.String, str]) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromFile(name: typing.Union[java.lang.String, str], codec: Codec) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromFile(uri: java.net.URI, enc: typing.Union[java.lang.String, str]) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromFile(uri: java.net.URI, codec: Codec) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromInputStream(is_: java.io.InputStream, enc: typing.Union[java.lang.String, str]) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromInputStream(is_: java.io.InputStream, codec: Codec) -> BufferedSource: ...
    @staticmethod
    def fromIterable(iterable: scala.collection.Iterable[typing.Any]) -> 'Source': ...
    @staticmethod
    def fromRawBytes(bytes: typing.List[int]) -> 'Source': ...
    @staticmethod
    def fromResource(resource: typing.Union[java.lang.String, str], classLoader: java.lang.ClassLoader, codec: Codec) -> BufferedSource: ...
    @staticmethod
    def fromResource$default$2() -> java.lang.ClassLoader: ...
    @staticmethod
    def fromString(s: typing.Union[java.lang.String, str]) -> 'Source': ...
    @staticmethod
    def fromURI(uri: java.net.URI, codec: Codec) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromURL(s: typing.Union[java.lang.String, str], enc: typing.Union[java.lang.String, str]) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromURL(s: typing.Union[java.lang.String, str], codec: Codec) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromURL(url: java.net.URL, enc: typing.Union[java.lang.String, str]) -> BufferedSource: ...
    @typing.overload
    @staticmethod
    def fromURL(url: java.net.URL, codec: Codec) -> BufferedSource: ...
    def getLines(self) -> scala.collection.Iterator[java.lang.String]: ...
    _grouped__B = typing.TypeVar('_grouped__B')  # <B>
    def grouped(self, size: int) -> scala.collection.Iterator.GroupedIterator[_grouped__B]: ...
    def hasDefiniteSize(self) -> bool: ...
    def hasNext(self) -> bool: ...
    _indexOf_0__B = typing.TypeVar('_indexOf_0__B')  # <B>
    _indexOf_1__B = typing.TypeVar('_indexOf_1__B')  # <B>
    @typing.overload
    def indexOf(self, elem: _indexOf_0__B) -> int: ...
    @typing.overload
    def indexOf(self, elem: _indexOf_1__B, from_: int) -> int: ...
    @typing.overload
    def indexWhere(self, p: scala.Function1[typing.Any, typing.Any]) -> int: ...
    @typing.overload
    def indexWhere(self, p: scala.Function1[typing.Any, typing.Any], from_: int) -> int: ...
    def isEmpty(self) -> bool: ...
    def isTraversableAgain(self) -> bool: ...
    def iter(self) -> scala.collection.Iterator[typing.Any]: ...
    def length(self) -> int: ...
    _map__B = typing.TypeVar('_map__B')  # <B>
    def map(self, f: scala.Function1[typing.Any, _map__B]) -> scala.collection.Iterator[_map__B]: ...
    def max(self, cmp: scala.math.Ordering) -> typing.Any: ...
    def maxBy(self, f: scala.Function1, cmp: scala.math.Ordering) -> typing.Any: ...
    def min(self, cmp: scala.math.Ordering) -> typing.Any: ...
    def minBy(self, f: scala.Function1, cmp: scala.math.Ordering) -> typing.Any: ...
    @typing.overload
    def mkString(self) -> java.lang.String: ...
    @typing.overload
    def mkString(self, sep: typing.Union[java.lang.String, str]) -> java.lang.String: ...
    @typing.overload
    def mkString(self, start: typing.Union[java.lang.String, str], sep: typing.Union[java.lang.String, str], end: typing.Union[java.lang.String, str]) -> java.lang.String: ...
    def nerrors(self) -> int: ...
    def nerrors_$eq(self, x$1: int) -> None: ...
    def next(self) -> str: ...
    def nonEmpty(self) -> bool: ...
    def nwarnings(self) -> int: ...
    def nwarnings_$eq(self, x$1: int) -> None: ...
    _padTo__A1 = typing.TypeVar('_padTo__A1')  # <A1>
    def padTo(self, len: int, elem: _padTo__A1) -> scala.collection.Iterator[_padTo__A1]: ...
    def partition(self, p: scala.Function1[typing.Any, typing.Any]) -> scala.Tuple2[scala.collection.Iterator[typing.Any], scala.collection.Iterator[typing.Any]]: ...
    _patch__B = typing.TypeVar('_patch__B')  # <B>
    def patch(self, from_: int, patchElems: scala.collection.Iterator[_patch__B], replaced: int) -> scala.collection.Iterator[_patch__B]: ...
    def pos(self) -> int: ...
    _product__B = typing.TypeVar('_product__B')  # <B>
    def product(self, num: scala.math.Numeric[_product__B]) -> _product__B: ...
    _reduce__A1 = typing.TypeVar('_reduce__A1')  # <A1>
    def reduce(self, op: scala.Function2[_reduce__A1, _reduce__A1, _reduce__A1]) -> _reduce__A1: ...
    _reduceLeft__B = typing.TypeVar('_reduceLeft__B')  # <B>
    def reduceLeft(self, op: scala.Function2[_reduceLeft__B, typing.Any, _reduceLeft__B]) -> _reduceLeft__B: ...
    _reduceLeftOption__B = typing.TypeVar('_reduceLeftOption__B')  # <B>
    def reduceLeftOption(self, op: scala.Function2[_reduceLeftOption__B, typing.Any, _reduceLeftOption__B]) -> scala.Option[_reduceLeftOption__B]: ...
    _reduceOption__A1 = typing.TypeVar('_reduceOption__A1')  # <A1>
    def reduceOption(self, op: scala.Function2[_reduceOption__A1, _reduceOption__A1, _reduceOption__A1]) -> scala.Option[_reduceOption__A1]: ...
    _reduceRight__B = typing.TypeVar('_reduceRight__B')  # <B>
    def reduceRight(self, op: scala.Function2[typing.Any, _reduceRight__B, _reduceRight__B]) -> _reduceRight__B: ...
    _reduceRightOption__B = typing.TypeVar('_reduceRightOption__B')  # <B>
    def reduceRightOption(self, op: scala.Function2[typing.Any, _reduceRightOption__B, _reduceRightOption__B]) -> scala.Option[_reduceRightOption__B]: ...
    def report(self, pos: int, msg: typing.Union[java.lang.String, str], out: java.io.PrintStream) -> None: ...
    def reportError(self, pos: int, msg: typing.Union[java.lang.String, str], out: java.io.PrintStream) -> None: ...
    def reportError$default$3(self) -> java.io.PrintStream: ...
    def reportWarning(self, pos: int, msg: typing.Union[java.lang.String, str], out: java.io.PrintStream) -> None: ...
    def reportWarning$default$3(self) -> java.io.PrintStream: ...
    def reset(self) -> 'Source': ...
    def reversed(self) -> scala.collection.immutable.List[typing.Any]: ...
    def sameElements(self, that: scala.collection.Iterator[typing.Any]) -> bool: ...
    _scanLeft__B = typing.TypeVar('_scanLeft__B')  # <B>
    def scanLeft(self, z: _scanLeft__B, op: scala.Function2[_scanLeft__B, typing.Any, _scanLeft__B]) -> scala.collection.Iterator[_scanLeft__B]: ...
    _scanRight__B = typing.TypeVar('_scanRight__B')  # <B>
    def scanRight(self, z: _scanRight__B, op: scala.Function2[typing.Any, _scanRight__B, _scanRight__B]) -> scala.collection.Iterator[_scanRight__B]: ...
    def seq(self) -> scala.collection.Iterator[typing.Any]: ...
    def size(self) -> int: ...
    def sizeHintIfCheap(self) -> int: ...
    def slice(self, from_: int, until: int) -> scala.collection.Iterator[typing.Any]: ...
    def sliceIterator(self, from_: int, until: int) -> scala.collection.Iterator[typing.Any]: ...
    _sliding__B = typing.TypeVar('_sliding__B')  # <B>
    def sliding(self, size: int, step: int) -> scala.collection.Iterator.GroupedIterator[_sliding__B]: ...
    _sliding$default$2__B = typing.TypeVar('_sliding$default$2__B')  # <B>
    def sliding$default$2(self) -> int: ...
    def span(self, p: scala.Function1[typing.Any, typing.Any]) -> scala.Tuple2[scala.collection.Iterator[typing.Any], scala.collection.Iterator[typing.Any]]: ...
    @staticmethod
    def stdin() -> BufferedSource: ...
    _sum__B = typing.TypeVar('_sum__B')  # <B>
    def sum(self, num: scala.math.Numeric[_sum__B]) -> _sum__B: ...
    def take(self, n: int) -> scala.collection.Iterator[typing.Any]: ...
    def takeWhile(self, p: scala.Function1[typing.Any, typing.Any]) -> scala.collection.Iterator[typing.Any]: ...
    _to__Col = typing.TypeVar('_to__Col')  # <Col>
    def to(self, cbf: scala.collection.generic.CanBuildFrom[scala.runtime.Nothing., typing.Any, _to__Col]) -> _to__Col: ...
    _toArray__B = typing.TypeVar('_toArray__B')  # <B>
    def toArray(self, evidence$1: scala.reflect.ClassTag[_toArray__B]) -> typing.Any: ...
    _toBuffer__B = typing.TypeVar('_toBuffer__B')  # <B>
    def toBuffer(self) -> scala.collection.mutable.Buffer[_toBuffer__B]: ...
    def toIndexedSeq(self) -> scala.collection.immutable.IndexedSeq[typing.Any]: ...
    def toIterable(self) -> scala.collection.Iterable[typing.Any]: ...
    def toIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def toList(self) -> scala.collection.immutable.List[typing.Any]: ...
    _toMap__T = typing.TypeVar('_toMap__T')  # <T>
    _toMap__U = typing.TypeVar('_toMap__U')  # <U>
    def toMap(self, ev: scala.Predef..less.colon.less[typing.Any, scala.Tuple2[_toMap__T, _toMap__U]]) -> scala.collection.immutable.Map[_toMap__T, _toMap__U]: ...
    def toSeq(self) -> scala.collection.Seq[typing.Any]: ...
    _toSet__B = typing.TypeVar('_toSet__B')  # <B>
    def toSet(self) -> scala.collection.immutable.Set[_toSet__B]: ...
    def toStream(self) -> scala.collection.immutable.Stream[typing.Any]: ...
    def toString(self) -> java.lang.String: ...
    def toTraversable(self) -> scala.collection.Traversable[typing.Any]: ...
    def toVector(self) -> scala.collection.immutable.Vector[typing.Any]: ...
    def withClose(self, f: scala.Function0[scala.runtime.BoxedUnit]) -> 'Source': ...
    def withDescription(self, text: typing.Union[java.lang.String, str]) -> 'Source': ...
    def withFilter(self, p: scala.Function1[typing.Any, typing.Any]) -> scala.collection.Iterator[typing.Any]: ...
    @typing.overload
    def withPositioning(self, on: bool) -> 'Source': ...
    @typing.overload
    def withPositioning(self, pos: 'Source.Positioner') -> 'Source': ...
    def withReset(self, f: scala.Function0['Source']) -> 'Source': ...
    _zip__B = typing.TypeVar('_zip__B')  # <B>
    def zip(self, that: scala.collection.Iterator[_zip__B]) -> scala.collection.Iterator[scala.Tuple2[typing.Any, _zip__B]]: ...
    _zipAll__B = typing.TypeVar('_zipAll__B')  # <B>
    _zipAll__A1 = typing.TypeVar('_zipAll__A1')  # <A1>
    _zipAll__B1 = typing.TypeVar('_zipAll__B1')  # <B1>
    def zipAll(self, that: scala.collection.Iterator[_zipAll__B], thisElem: _zipAll__A1, thatElem: _zipAll__B1) -> scala.collection.Iterator[scala.Tuple2[_zipAll__A1, _zipAll__B1]]: ...
    def zipWithIndex(self) -> scala.collection.Iterator[scala.Tuple2[typing.Any, typing.Any]]: ...
    class LineIterator(scala.collection.AbstractIterator[java.lang.String]):
        $outer: 'Source' = ...
        def __init__(self, $outer: 'Source'): ...
        def getc(self) -> bool: ...
        def hasNext(self) -> bool: ...
        def isNewline(self, ch: str) -> bool: ...
        def iter(self) -> scala.collection.BufferedIterator[typing.Any]: ...
        def next(self) -> java.lang.String: ...
    class NoPositioner$(scala.io.Source.Positioner):
        def __init__(self, $outer: 'Source'): ...
        def next(self) -> str: ...
    class Positioner:
        $outer: 'Source' = ...
        @typing.overload
        def __init__(self, $outer: 'Source'): ...
        @typing.overload
        def __init__(self, $outer: 'Source', encoder: Position): ...
        def ccol(self) -> int: ...
        def ccol_$eq(self, x$1: int) -> None: ...
        def ch(self) -> str: ...
        def ch_$eq(self, x$1: str) -> None: ...
        def cline(self) -> int: ...
        def cline_$eq(self, x$1: int) -> None: ...
        def next(self) -> str: ...
        def pos(self) -> int: ...
        def pos_$eq(self, x$1: int) -> None: ...
        def tabinc(self) -> int: ...
        def tabinc_$eq(self, x$1: int) -> None: ...
    class RelaxedPosition$(Position):
        def __init__(self, $outer: 'Source'): ...
        def checkInput(self, line: int, column: int) -> None: ...
    class RelaxedPositioner$(scala.io.Source.Positioner):
        def __init__(self, $outer: 'Source'): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.io")``.

    AnsiColor: typing.Type[AnsiColor]
    BufferedSource: typing.Type[BufferedSource]
    Codec: typing.Type[Codec]
    LowPriorityCodecImplicits: typing.Type[LowPriorityCodecImplicits]
    Position: typing.Type[Position]
    Source: typing.Type[Source]
    StdIn: typing.Type[StdIn]



import java.io
import java.lang
import java.net
import java.util
import jpype.protocol
import typing



class AboutHandler:
    def handleAbout(self, aboutEvent: 'AboutEvent') -> None: ...

class AppEvent(java.util.EventObject): ...

class OpenFilesHandler:
    def openFiles(self, openFilesEvent: 'OpenFilesEvent') -> None: ...

class OpenURIHandler:
    def openURI(self, openURIEvent: 'OpenURIEvent') -> None: ...

class PreferencesHandler:
    def handlePreferences(self, preferencesEvent: 'PreferencesEvent') -> None: ...

class PrintFilesHandler:
    def printFiles(self, printFilesEvent: 'PrintFilesEvent') -> None: ...

class QuitHandler:
    def handleQuitRequestWith(self, quitEvent: 'QuitEvent', quitResponse: 'QuitResponse') -> None: ...

class QuitResponse:
    def cancelQuit(self) -> None: ...
    def performQuit(self) -> None: ...

class QuitStrategy(java.lang.Enum['QuitStrategy']):
    NORMAL_EXIT: typing.ClassVar['QuitStrategy'] = ...
    CLOSE_ALL_WINDOWS: typing.ClassVar['QuitStrategy'] = ...
    _valueOf_1__T = typing.TypeVar('_valueOf_1__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'QuitStrategy': ...
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_1__T], string: str) -> _valueOf_1__T: ...
    @staticmethod
    def values() -> typing.List['QuitStrategy']: ...

class SystemEventListener(java.util.EventListener): ...

class AboutEvent(AppEvent):
    def __init__(self): ...

class AppForegroundEvent(AppEvent):
    def __init__(self): ...

class AppForegroundListener(SystemEventListener):
    def appMovedToBackground(self, appForegroundEvent: AppForegroundEvent) -> None: ...
    def appRaisedToForeground(self, appForegroundEvent: AppForegroundEvent) -> None: ...

class AppHiddenEvent(AppEvent):
    def __init__(self): ...

class AppHiddenListener(SystemEventListener):
    def appHidden(self, appHiddenEvent: AppHiddenEvent) -> None: ...
    def appUnhidden(self, appHiddenEvent: AppHiddenEvent) -> None: ...

class AppReopenedEvent(AppEvent):
    def __init__(self): ...

class AppReopenedListener(SystemEventListener):
    def appReopened(self, appReopenedEvent: AppReopenedEvent) -> None: ...

class FilesEvent(AppEvent):
    def getFiles(self) -> java.util.List[java.io.File]: ...

class OpenURIEvent(AppEvent):
    def __init__(self, uRI: java.net.URI): ...
    def getURI(self) -> java.net.URI: ...

class PreferencesEvent(AppEvent):
    def __init__(self): ...

class QuitEvent(AppEvent):
    def __init__(self): ...

class ScreenSleepEvent(AppEvent):
    def __init__(self): ...

class ScreenSleepListener(SystemEventListener):
    def screenAboutToSleep(self, screenSleepEvent: ScreenSleepEvent) -> None: ...
    def screenAwoke(self, screenSleepEvent: ScreenSleepEvent) -> None: ...

class SystemSleepEvent(AppEvent):
    def __init__(self): ...

class SystemSleepListener(SystemEventListener):
    def systemAboutToSleep(self, systemSleepEvent: SystemSleepEvent) -> None: ...
    def systemAwoke(self, systemSleepEvent: SystemSleepEvent) -> None: ...

class UserSessionEvent(AppEvent):
    def __init__(self, reason: 'UserSessionEvent.Reason'): ...
    def getReason(self) -> 'UserSessionEvent.Reason': ...
    class Reason(java.lang.Enum['UserSessionEvent.Reason']):
        UNSPECIFIED: typing.ClassVar['UserSessionEvent.Reason'] = ...
        CONSOLE: typing.ClassVar['UserSessionEvent.Reason'] = ...
        REMOTE: typing.ClassVar['UserSessionEvent.Reason'] = ...
        LOCK: typing.ClassVar['UserSessionEvent.Reason'] = ...
        _valueOf_1__T = typing.TypeVar('_valueOf_1__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'UserSessionEvent.Reason': ...
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_1__T], string: str) -> _valueOf_1__T: ...
        @staticmethod
        def values() -> typing.List['UserSessionEvent.Reason']: ...

class UserSessionListener(SystemEventListener):
    def userSessionActivated(self, userSessionEvent: UserSessionEvent) -> None: ...
    def userSessionDeactivated(self, userSessionEvent: UserSessionEvent) -> None: ...

class OpenFilesEvent(FilesEvent):
    def __init__(self, list: java.util.List[typing.Union[java.io.File, jpype.protocol.SupportsPath]], string: str): ...
    def getSearchTerm(self) -> str: ...

class PrintFilesEvent(FilesEvent):
    def __init__(self, list: java.util.List[typing.Union[java.io.File, jpype.protocol.SupportsPath]]): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.desktop")``.

    AboutEvent: typing.Type[AboutEvent]
    AboutHandler: typing.Type[AboutHandler]
    AppEvent: typing.Type[AppEvent]
    AppForegroundEvent: typing.Type[AppForegroundEvent]
    AppForegroundListener: typing.Type[AppForegroundListener]
    AppHiddenEvent: typing.Type[AppHiddenEvent]
    AppHiddenListener: typing.Type[AppHiddenListener]
    AppReopenedEvent: typing.Type[AppReopenedEvent]
    AppReopenedListener: typing.Type[AppReopenedListener]
    FilesEvent: typing.Type[FilesEvent]
    OpenFilesEvent: typing.Type[OpenFilesEvent]
    OpenFilesHandler: typing.Type[OpenFilesHandler]
    OpenURIEvent: typing.Type[OpenURIEvent]
    OpenURIHandler: typing.Type[OpenURIHandler]
    PreferencesEvent: typing.Type[PreferencesEvent]
    PreferencesHandler: typing.Type[PreferencesHandler]
    PrintFilesEvent: typing.Type[PrintFilesEvent]
    PrintFilesHandler: typing.Type[PrintFilesHandler]
    QuitEvent: typing.Type[QuitEvent]
    QuitHandler: typing.Type[QuitHandler]
    QuitResponse: typing.Type[QuitResponse]
    QuitStrategy: typing.Type[QuitStrategy]
    ScreenSleepEvent: typing.Type[ScreenSleepEvent]
    ScreenSleepListener: typing.Type[ScreenSleepListener]
    SystemEventListener: typing.Type[SystemEventListener]
    SystemSleepEvent: typing.Type[SystemSleepEvent]
    SystemSleepListener: typing.Type[SystemSleepListener]
    UserSessionEvent: typing.Type[UserSessionEvent]
    UserSessionListener: typing.Type[UserSessionListener]



import java.lang
import org.ergoplatform
import org.ergoplatform.wallet.boxes
import scala
import scala.collection
import scala.collection.immutable
import scala.util
import special.collection
import typing



class TransactionBuilder:
    @staticmethod
    def buildUnsignedTx(inputs: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], dataInputs: scala.collection.IndexedSeq[org.ergoplatform.DataInput], outputCandidates: scala.collection.Seq[org.ergoplatform.ErgoBoxCandidate], currentHeight: int, createFeeOutput: scala.Option[typing.Any], changeAddress: org.ergoplatform.ErgoAddress, minChangeValue: int, minerRewardDelay: int, burnTokens: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any], boxSelector: org.ergoplatform.wallet.boxes.BoxSelector) -> scala.util.Try[org.ergoplatform.UnsignedErgoLikeTransaction]: ...
    @staticmethod
    def buildUnsignedTx$default$10() -> org.ergoplatform.wallet.boxes.BoxSelector: ...
    @staticmethod
    def buildUnsignedTx$default$9() -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
    @staticmethod
    def collTokensToMap(tokens: special.collection.Coll[scala.Tuple2[typing.List[int], typing.Any]]) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
    @staticmethod
    def collectOutputTokens(outputCandidates: scala.collection.Seq[org.ergoplatform.ErgoBoxCandidate]) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
    @staticmethod
    def tokensMapToColl(tokens: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> special.collection.Coll[scala.Tuple2[typing.List[int], typing.Any]]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.transactions")``.

    TransactionBuilder: typing.Type[TransactionBuilder]



import java.io
import java.lang
import java.net
import java.nio
import java.nio.charset
import java.nio.file
import java.time
import java.util
import java.util.concurrent
import java.util.function
import java.util.stream
import javax.net.ssl
import jpype.protocol
import typing



class HttpClient:
    def authenticator(self) -> java.util.Optional[java.net.Authenticator]: ...
    def connectTimeout(self) -> java.util.Optional[java.time.Duration]: ...
    def cookieHandler(self) -> java.util.Optional[java.net.CookieHandler]: ...
    def executor(self) -> java.util.Optional[java.util.concurrent.Executor]: ...
    def followRedirects(self) -> 'HttpClient.Redirect': ...
    @staticmethod
    def newBuilder() -> 'HttpClient.Builder': ...
    @staticmethod
    def newHttpClient() -> 'HttpClient': ...
    def newWebSocketBuilder(self) -> 'WebSocket.Builder': ...
    def proxy(self) -> java.util.Optional[java.net.ProxySelector]: ...
    _send__T = typing.TypeVar('_send__T')  # <T>
    def send(self, httpRequest: 'HttpRequest', bodyHandler: typing.Union['HttpResponse.BodyHandler'[_send__T], typing.Callable[['HttpResponse.ResponseInfo'], 'HttpResponse.BodySubscriber'[typing.Any]]]) -> 'HttpResponse'[_send__T]: ...
    _sendAsync_0__T = typing.TypeVar('_sendAsync_0__T')  # <T>
    _sendAsync_1__T = typing.TypeVar('_sendAsync_1__T')  # <T>
    @typing.overload
    def sendAsync(self, httpRequest: 'HttpRequest', bodyHandler: typing.Union['HttpResponse.BodyHandler'[_sendAsync_0__T], typing.Callable[['HttpResponse.ResponseInfo'], 'HttpResponse.BodySubscriber'[typing.Any]]]) -> java.util.concurrent.CompletableFuture['HttpResponse'[_sendAsync_0__T]]: ...
    @typing.overload
    def sendAsync(self, httpRequest: 'HttpRequest', bodyHandler: typing.Union['HttpResponse.BodyHandler'[_sendAsync_1__T], typing.Callable[['HttpResponse.ResponseInfo'], 'HttpResponse.BodySubscriber'[typing.Any]]], pushPromiseHandler: 'HttpResponse.PushPromiseHandler'[_sendAsync_1__T]) -> java.util.concurrent.CompletableFuture['HttpResponse'[_sendAsync_1__T]]: ...
    def sslContext(self) -> javax.net.ssl.SSLContext: ...
    def sslParameters(self) -> javax.net.ssl.SSLParameters: ...
    def version(self) -> 'HttpClient.Version': ...
    class Builder:
        NO_PROXY: typing.ClassVar[java.net.ProxySelector] = ...
        def authenticator(self, authenticator: java.net.Authenticator) -> 'HttpClient.Builder': ...
        def build(self) -> 'HttpClient': ...
        def connectTimeout(self, duration: java.time.Duration) -> 'HttpClient.Builder': ...
        def cookieHandler(self, cookieHandler: java.net.CookieHandler) -> 'HttpClient.Builder': ...
        def executor(self, executor: java.util.concurrent.Executor) -> 'HttpClient.Builder': ...
        def followRedirects(self, redirect: 'HttpClient.Redirect') -> 'HttpClient.Builder': ...
        def priority(self, int: int) -> 'HttpClient.Builder': ...
        def proxy(self, proxySelector: java.net.ProxySelector) -> 'HttpClient.Builder': ...
        def sslContext(self, sSLContext: javax.net.ssl.SSLContext) -> 'HttpClient.Builder': ...
        def sslParameters(self, sSLParameters: javax.net.ssl.SSLParameters) -> 'HttpClient.Builder': ...
        def version(self, version: 'HttpClient.Version') -> 'HttpClient.Builder': ...
    class Redirect(java.lang.Enum['HttpClient.Redirect']):
        NEVER: typing.ClassVar['HttpClient.Redirect'] = ...
        ALWAYS: typing.ClassVar['HttpClient.Redirect'] = ...
        NORMAL: typing.ClassVar['HttpClient.Redirect'] = ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'HttpClient.Redirect': ...
        @staticmethod
        def values() -> typing.List['HttpClient.Redirect']: ...
    class Version(java.lang.Enum['HttpClient.Version']):
        HTTP_1_1: typing.ClassVar['HttpClient.Version'] = ...
        HTTP_2: typing.ClassVar['HttpClient.Version'] = ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'HttpClient.Version': ...
        @staticmethod
        def values() -> typing.List['HttpClient.Version']: ...

class HttpHeaders:
    def allValues(self, string: str) -> java.util.List[str]: ...
    def equals(self, object: typing.Any) -> bool: ...
    def firstValue(self, string: str) -> java.util.Optional[str]: ...
    def firstValueAsLong(self, string: str) -> java.util.OptionalLong: ...
    def hashCode(self) -> int: ...
    def map(self) -> java.util.Map[str, java.util.List[str]]: ...
    @staticmethod
    def of(map: typing.Union[java.util.Map[str, java.util.List[str]], typing.Mapping[str, java.util.List[str]]], biPredicate: typing.Union[java.util.function.BiPredicate[str, str], typing.Callable[[str, str], bool]]) -> 'HttpHeaders': ...
    def toString(self) -> str: ...

class HttpRequest:
    def bodyPublisher(self) -> java.util.Optional['HttpRequest.BodyPublisher']: ...
    def equals(self, object: typing.Any) -> bool: ...
    def expectContinue(self) -> bool: ...
    def hashCode(self) -> int: ...
    def headers(self) -> HttpHeaders: ...
    def method(self) -> str: ...
    @typing.overload
    @staticmethod
    def newBuilder() -> 'HttpRequest.Builder': ...
    @typing.overload
    @staticmethod
    def newBuilder(uRI: java.net.URI) -> 'HttpRequest.Builder': ...
    def timeout(self) -> java.util.Optional[java.time.Duration]: ...
    def uri(self) -> java.net.URI: ...
    def version(self) -> java.util.Optional[HttpClient.Version]: ...
    class BodyPublisher(java.util.concurrent.Flow.Publisher[java.nio.ByteBuffer]):
        def contentLength(self) -> int: ...
    class BodyPublishers:
        @typing.overload
        @staticmethod
        def fromPublisher(publisher: typing.Union[java.util.concurrent.Flow.Publisher[java.nio.ByteBuffer], typing.Callable[[java.util.concurrent.Flow.Subscriber[typing.Any]], None]]) -> 'HttpRequest.BodyPublisher': ...
        @typing.overload
        @staticmethod
        def fromPublisher(publisher: typing.Union[java.util.concurrent.Flow.Publisher[java.nio.ByteBuffer], typing.Callable[[java.util.concurrent.Flow.Subscriber[typing.Any]], None]], long: int) -> 'HttpRequest.BodyPublisher': ...
        @staticmethod
        def noBody() -> 'HttpRequest.BodyPublisher': ...
        @typing.overload
        @staticmethod
        def ofByteArray(byteArray: typing.List[int]) -> 'HttpRequest.BodyPublisher': ...
        @typing.overload
        @staticmethod
        def ofByteArray(byteArray: typing.List[int], int: int, int2: int) -> 'HttpRequest.BodyPublisher': ...
        @staticmethod
        def ofByteArrays(iterable: typing.Union[java.lang.Iterable[typing.List[int]], typing.Sequence[typing.List[int]], typing.Set[typing.List[int]]]) -> 'HttpRequest.BodyPublisher': ...
        @staticmethod
        def ofFile(path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> 'HttpRequest.BodyPublisher': ...
        @staticmethod
        def ofInputStream(supplier: typing.Union[java.util.function.Supplier[java.io.InputStream], typing.Callable[[], java.io.InputStream]]) -> 'HttpRequest.BodyPublisher': ...
        @typing.overload
        @staticmethod
        def ofString(string: str) -> 'HttpRequest.BodyPublisher': ...
        @typing.overload
        @staticmethod
        def ofString(string: str, charset: java.nio.charset.Charset) -> 'HttpRequest.BodyPublisher': ...
    class Builder:
        def DELETE(self) -> 'HttpRequest.Builder': ...
        def GET(self) -> 'HttpRequest.Builder': ...
        def POST(self, bodyPublisher: 'HttpRequest.BodyPublisher') -> 'HttpRequest.Builder': ...
        def PUT(self, bodyPublisher: 'HttpRequest.BodyPublisher') -> 'HttpRequest.Builder': ...
        def build(self) -> 'HttpRequest': ...
        def copy(self) -> 'HttpRequest.Builder': ...
        def expectContinue(self, boolean: bool) -> 'HttpRequest.Builder': ...
        def header(self, string: str, string2: str) -> 'HttpRequest.Builder': ...
        def headers(self, stringArray: typing.List[str]) -> 'HttpRequest.Builder': ...
        def method(self, string: str, bodyPublisher: 'HttpRequest.BodyPublisher') -> 'HttpRequest.Builder': ...
        def setHeader(self, string: str, string2: str) -> 'HttpRequest.Builder': ...
        def timeout(self, duration: java.time.Duration) -> 'HttpRequest.Builder': ...
        def uri(self, uRI: java.net.URI) -> 'HttpRequest.Builder': ...
        def version(self, version: HttpClient.Version) -> 'HttpRequest.Builder': ...

_HttpResponse__BodyHandler__T = typing.TypeVar('_HttpResponse__BodyHandler__T')  # <T>
_HttpResponse__BodySubscriber__T = typing.TypeVar('_HttpResponse__BodySubscriber__T')  # <T>
_HttpResponse__PushPromiseHandler__T = typing.TypeVar('_HttpResponse__PushPromiseHandler__T')  # <T>
_HttpResponse__T = typing.TypeVar('_HttpResponse__T')  # <T>
class HttpResponse(typing.Generic[_HttpResponse__T]):
    def body(self) -> _HttpResponse__T: ...
    def headers(self) -> HttpHeaders: ...
    def previousResponse(self) -> java.util.Optional['HttpResponse'[_HttpResponse__T]]: ...
    def request(self) -> HttpRequest: ...
    def sslSession(self) -> java.util.Optional[javax.net.ssl.SSLSession]: ...
    def statusCode(self) -> int: ...
    def uri(self) -> java.net.URI: ...
    def version(self) -> HttpClient.Version: ...
    class BodyHandler(typing.Generic[_HttpResponse__BodyHandler__T]):
        def apply(self, responseInfo: 'HttpResponse.ResponseInfo') -> 'HttpResponse.BodySubscriber'[_HttpResponse__BodyHandler__T]: ...
    class BodyHandlers:
        _buffering__T = typing.TypeVar('_buffering__T')  # <T>
        @staticmethod
        def buffering(bodyHandler: typing.Union['HttpResponse.BodyHandler'[_buffering__T], typing.Callable[['HttpResponse.ResponseInfo'], 'HttpResponse.BodySubscriber'[typing.Any]]], int: int) -> 'HttpResponse.BodyHandler'[_buffering__T]: ...
        @staticmethod
        def discarding() -> 'HttpResponse.BodyHandler'[None]: ...
        _fromLineSubscriber_1__S = typing.TypeVar('_fromLineSubscriber_1__S', bound=java.util.concurrent.Flow.Subscriber)  # <S>
        _fromLineSubscriber_1__T = typing.TypeVar('_fromLineSubscriber_1__T')  # <T>
        @typing.overload
        @staticmethod
        def fromLineSubscriber(subscriber: java.util.concurrent.Flow.Subscriber[str]) -> 'HttpResponse.BodyHandler'[None]: ...
        @typing.overload
        @staticmethod
        def fromLineSubscriber(s: _fromLineSubscriber_1__S, function: typing.Union[java.util.function.Function[_fromLineSubscriber_1__S, _fromLineSubscriber_1__T], typing.Callable[[_fromLineSubscriber_1__S], _fromLineSubscriber_1__T]], string: str) -> 'HttpResponse.BodyHandler'[_fromLineSubscriber_1__T]: ...
        _fromSubscriber_1__S = typing.TypeVar('_fromSubscriber_1__S', bound=java.util.concurrent.Flow.Subscriber)  # <S>
        _fromSubscriber_1__T = typing.TypeVar('_fromSubscriber_1__T')  # <T>
        @typing.overload
        @staticmethod
        def fromSubscriber(subscriber: java.util.concurrent.Flow.Subscriber[java.util.List[java.nio.ByteBuffer]]) -> 'HttpResponse.BodyHandler'[None]: ...
        @typing.overload
        @staticmethod
        def fromSubscriber(s: _fromSubscriber_1__S, function: typing.Union[java.util.function.Function[_fromSubscriber_1__S, _fromSubscriber_1__T], typing.Callable[[_fromSubscriber_1__S], _fromSubscriber_1__T]]) -> 'HttpResponse.BodyHandler'[_fromSubscriber_1__T]: ...
        @staticmethod
        def ofByteArray() -> 'HttpResponse.BodyHandler'[typing.List[int]]: ...
        @staticmethod
        def ofByteArrayConsumer(consumer: typing.Union[java.util.function.Consumer[java.util.Optional[typing.List[int]]], typing.Callable[[java.util.Optional[typing.List[int]]], None]]) -> 'HttpResponse.BodyHandler'[None]: ...
        @typing.overload
        @staticmethod
        def ofFile(path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> 'HttpResponse.BodyHandler'[java.nio.file.Path]: ...
        @typing.overload
        @staticmethod
        def ofFile(path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], openOptionArray: typing.List[java.nio.file.OpenOption]) -> 'HttpResponse.BodyHandler'[java.nio.file.Path]: ...
        @staticmethod
        def ofFileDownload(path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], openOptionArray: typing.List[java.nio.file.OpenOption]) -> 'HttpResponse.BodyHandler'[java.nio.file.Path]: ...
        @staticmethod
        def ofInputStream() -> 'HttpResponse.BodyHandler'[java.io.InputStream]: ...
        @staticmethod
        def ofLines() -> 'HttpResponse.BodyHandler'[java.util.stream.Stream[str]]: ...
        @staticmethod
        def ofPublisher() -> 'HttpResponse.BodyHandler'[java.util.concurrent.Flow.Publisher[java.util.List[java.nio.ByteBuffer]]]: ...
        @typing.overload
        @staticmethod
        def ofString() -> 'HttpResponse.BodyHandler'[str]: ...
        @typing.overload
        @staticmethod
        def ofString(charset: java.nio.charset.Charset) -> 'HttpResponse.BodyHandler'[str]: ...
        _replacing__U = typing.TypeVar('_replacing__U')  # <U>
        @staticmethod
        def replacing(u: _replacing__U) -> 'HttpResponse.BodyHandler'[_replacing__U]: ...
    class BodySubscriber(java.util.concurrent.Flow.Subscriber[java.util.List[java.nio.ByteBuffer]], typing.Generic[_HttpResponse__BodySubscriber__T]):
        def getBody(self) -> java.util.concurrent.CompletionStage[_HttpResponse__BodySubscriber__T]: ...
    class BodySubscribers:
        _buffering__T = typing.TypeVar('_buffering__T')  # <T>
        @staticmethod
        def buffering(bodySubscriber: 'HttpResponse.BodySubscriber'[_buffering__T], int: int) -> 'HttpResponse.BodySubscriber'[_buffering__T]: ...
        @staticmethod
        def discarding() -> 'HttpResponse.BodySubscriber'[None]: ...
        _fromLineSubscriber_1__S = typing.TypeVar('_fromLineSubscriber_1__S', bound=java.util.concurrent.Flow.Subscriber)  # <S>
        _fromLineSubscriber_1__T = typing.TypeVar('_fromLineSubscriber_1__T')  # <T>
        @typing.overload
        @staticmethod
        def fromLineSubscriber(subscriber: java.util.concurrent.Flow.Subscriber[str]) -> 'HttpResponse.BodySubscriber'[None]: ...
        @typing.overload
        @staticmethod
        def fromLineSubscriber(s: _fromLineSubscriber_1__S, function: typing.Union[java.util.function.Function[_fromLineSubscriber_1__S, _fromLineSubscriber_1__T], typing.Callable[[_fromLineSubscriber_1__S], _fromLineSubscriber_1__T]], charset: java.nio.charset.Charset, string: str) -> 'HttpResponse.BodySubscriber'[_fromLineSubscriber_1__T]: ...
        _fromSubscriber_1__S = typing.TypeVar('_fromSubscriber_1__S', bound=java.util.concurrent.Flow.Subscriber)  # <S>
        _fromSubscriber_1__T = typing.TypeVar('_fromSubscriber_1__T')  # <T>
        @typing.overload
        @staticmethod
        def fromSubscriber(subscriber: java.util.concurrent.Flow.Subscriber[java.util.List[java.nio.ByteBuffer]]) -> 'HttpResponse.BodySubscriber'[None]: ...
        @typing.overload
        @staticmethod
        def fromSubscriber(s: _fromSubscriber_1__S, function: typing.Union[java.util.function.Function[_fromSubscriber_1__S, _fromSubscriber_1__T], typing.Callable[[_fromSubscriber_1__S], _fromSubscriber_1__T]]) -> 'HttpResponse.BodySubscriber'[_fromSubscriber_1__T]: ...
        _mapping__T = typing.TypeVar('_mapping__T')  # <T>
        _mapping__U = typing.TypeVar('_mapping__U')  # <U>
        @staticmethod
        def mapping(bodySubscriber: 'HttpResponse.BodySubscriber'[_mapping__T], function: typing.Union[java.util.function.Function[_mapping__T, _mapping__U], typing.Callable[[_mapping__T], _mapping__U]]) -> 'HttpResponse.BodySubscriber'[_mapping__U]: ...
        @staticmethod
        def ofByteArray() -> 'HttpResponse.BodySubscriber'[typing.List[int]]: ...
        @staticmethod
        def ofByteArrayConsumer(consumer: typing.Union[java.util.function.Consumer[java.util.Optional[typing.List[int]]], typing.Callable[[java.util.Optional[typing.List[int]]], None]]) -> 'HttpResponse.BodySubscriber'[None]: ...
        @typing.overload
        @staticmethod
        def ofFile(path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> 'HttpResponse.BodySubscriber'[java.nio.file.Path]: ...
        @typing.overload
        @staticmethod
        def ofFile(path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], openOptionArray: typing.List[java.nio.file.OpenOption]) -> 'HttpResponse.BodySubscriber'[java.nio.file.Path]: ...
        @staticmethod
        def ofInputStream() -> 'HttpResponse.BodySubscriber'[java.io.InputStream]: ...
        @staticmethod
        def ofLines(charset: java.nio.charset.Charset) -> 'HttpResponse.BodySubscriber'[java.util.stream.Stream[str]]: ...
        @staticmethod
        def ofPublisher() -> 'HttpResponse.BodySubscriber'[java.util.concurrent.Flow.Publisher[java.util.List[java.nio.ByteBuffer]]]: ...
        @staticmethod
        def ofString(charset: java.nio.charset.Charset) -> 'HttpResponse.BodySubscriber'[str]: ...
        _replacing__U = typing.TypeVar('_replacing__U')  # <U>
        @staticmethod
        def replacing(u: _replacing__U) -> 'HttpResponse.BodySubscriber'[_replacing__U]: ...
    class PushPromiseHandler(typing.Generic[_HttpResponse__PushPromiseHandler__T]):
        def applyPushPromise(self, httpRequest: HttpRequest, httpRequest2: HttpRequest, function: typing.Union[java.util.function.Function[typing.Union['HttpResponse.BodyHandler'[_HttpResponse__PushPromiseHandler__T], typing.Callable[['HttpResponse.ResponseInfo'], 'HttpResponse.BodySubscriber'[typing.Any]]], java.util.concurrent.CompletableFuture['HttpResponse'[_HttpResponse__PushPromiseHandler__T]]], typing.Callable[[typing.Union['HttpResponse.BodyHandler'[_HttpResponse__PushPromiseHandler__T], typing.Callable[['HttpResponse.ResponseInfo'], 'HttpResponse.BodySubscriber'[typing.Any]]]], java.util.concurrent.CompletableFuture['HttpResponse'[_HttpResponse__PushPromiseHandler__T]]]]) -> None: ...
        _of__T = typing.TypeVar('_of__T')  # <T>
        @staticmethod
        def of(function: typing.Union[java.util.function.Function[HttpRequest, typing.Union['HttpResponse.BodyHandler'[_of__T], typing.Callable[['HttpResponse.ResponseInfo'], 'HttpResponse.BodySubscriber'[typing.Any]]]], typing.Callable[[HttpRequest], typing.Union['HttpResponse.BodyHandler'[_of__T], typing.Callable[['HttpResponse.ResponseInfo'], 'HttpResponse.BodySubscriber'[typing.Any]]]]], concurrentMap: java.util.concurrent.ConcurrentMap[HttpRequest, java.util.concurrent.CompletableFuture['HttpResponse'[_of__T]]]) -> 'HttpResponse.PushPromiseHandler'[_of__T]: ...
    class ResponseInfo:
        def headers(self) -> HttpHeaders: ...
        def statusCode(self) -> int: ...
        def version(self) -> HttpClient.Version: ...

class HttpTimeoutException(java.io.IOException):
    def __init__(self, string: str): ...

class WebSocket:
    NORMAL_CLOSURE: typing.ClassVar[int] = ...
    def abort(self) -> None: ...
    def getSubprotocol(self) -> str: ...
    def isInputClosed(self) -> bool: ...
    def isOutputClosed(self) -> bool: ...
    def request(self, long: int) -> None: ...
    def sendBinary(self, byteBuffer: java.nio.ByteBuffer, boolean: bool) -> java.util.concurrent.CompletableFuture['WebSocket']: ...
    def sendClose(self, int: int, string: str) -> java.util.concurrent.CompletableFuture['WebSocket']: ...
    def sendPing(self, byteBuffer: java.nio.ByteBuffer) -> java.util.concurrent.CompletableFuture['WebSocket']: ...
    def sendPong(self, byteBuffer: java.nio.ByteBuffer) -> java.util.concurrent.CompletableFuture['WebSocket']: ...
    def sendText(self, charSequence: typing.Union[java.lang.CharSequence, str], boolean: bool) -> java.util.concurrent.CompletableFuture['WebSocket']: ...
    class Builder:
        def buildAsync(self, uRI: java.net.URI, listener: 'WebSocket.Listener') -> java.util.concurrent.CompletableFuture['WebSocket']: ...
        def connectTimeout(self, duration: java.time.Duration) -> 'WebSocket.Builder': ...
        def header(self, string: str, string2: str) -> 'WebSocket.Builder': ...
        def subprotocols(self, string: str, stringArray: typing.List[str]) -> 'WebSocket.Builder': ...
    class Listener:
        def onBinary(self, webSocket: 'WebSocket', byteBuffer: java.nio.ByteBuffer, boolean: bool) -> java.util.concurrent.CompletionStage[typing.Any]: ...
        def onClose(self, webSocket: 'WebSocket', int: int, string: str) -> java.util.concurrent.CompletionStage[typing.Any]: ...
        def onError(self, webSocket: 'WebSocket', throwable: java.lang.Throwable) -> None: ...
        def onOpen(self, webSocket: 'WebSocket') -> None: ...
        def onPing(self, webSocket: 'WebSocket', byteBuffer: java.nio.ByteBuffer) -> java.util.concurrent.CompletionStage[typing.Any]: ...
        def onPong(self, webSocket: 'WebSocket', byteBuffer: java.nio.ByteBuffer) -> java.util.concurrent.CompletionStage[typing.Any]: ...
        def onText(self, webSocket: 'WebSocket', charSequence: typing.Union[java.lang.CharSequence, str], boolean: bool) -> java.util.concurrent.CompletionStage[typing.Any]: ...

class WebSocketHandshakeException(java.io.IOException):
    def __init__(self, httpResponse: HttpResponse[typing.Any]): ...
    def getResponse(self) -> HttpResponse[typing.Any]: ...
    def initCause(self, throwable: java.lang.Throwable) -> 'WebSocketHandshakeException': ...

class HttpConnectTimeoutException(HttpTimeoutException):
    def __init__(self, string: str): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.net.http")``.

    HttpClient: typing.Type[HttpClient]
    HttpConnectTimeoutException: typing.Type[HttpConnectTimeoutException]
    HttpHeaders: typing.Type[HttpHeaders]
    HttpRequest: typing.Type[HttpRequest]
    HttpResponse: typing.Type[HttpResponse]
    HttpTimeoutException: typing.Type[HttpTimeoutException]
    WebSocket: typing.Type[WebSocket]
    WebSocketHandshakeException: typing.Type[WebSocketHandshakeException]



import java.io
import java.net
import java.nio.channels
import java.nio.file
import java.nio.file.attribute
import java.util
import java.util.concurrent
import jpype.protocol
import typing



class FileSystemProvider:
    def checkAccess(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], accessModeArray: typing.List[java.nio.file.AccessMode]) -> None: ...
    def copy(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], path2: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], copyOptionArray: typing.List[java.nio.file.CopyOption]) -> None: ...
    def createDirectory(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> None: ...
    def createLink(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], path2: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> None: ...
    def createSymbolicLink(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], path2: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> None: ...
    def delete(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> None: ...
    def deleteIfExists(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> bool: ...
    _getFileAttributeView__V = typing.TypeVar('_getFileAttributeView__V', bound=java.nio.file.attribute.FileAttributeView)  # <V>
    def getFileAttributeView(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], class_: typing.Type[_getFileAttributeView__V], linkOptionArray: typing.List[java.nio.file.LinkOption]) -> _getFileAttributeView__V: ...
    def getFileStore(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> java.nio.file.FileStore: ...
    def getFileSystem(self, uRI: java.net.URI) -> java.nio.file.FileSystem: ...
    def getPath(self, uRI: java.net.URI) -> java.nio.file.Path: ...
    def getScheme(self) -> str: ...
    @staticmethod
    def installedProviders() -> java.util.List['FileSystemProvider']: ...
    def isHidden(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> bool: ...
    def isSameFile(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], path2: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> bool: ...
    def move(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], path2: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], copyOptionArray: typing.List[java.nio.file.CopyOption]) -> None: ...
    def newAsynchronousFileChannel(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], set: java.util.Set[java.nio.file.OpenOption], executorService: java.util.concurrent.ExecutorService, fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> java.nio.channels.AsynchronousFileChannel: ...
    def newByteChannel(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], set: java.util.Set[java.nio.file.OpenOption], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> java.nio.channels.SeekableByteChannel: ...
    def newDirectoryStream(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], filter: typing.Union[java.nio.file.DirectoryStream.Filter[java.nio.file.Path], typing.Callable[[java.nio.file.Path], bool]]) -> java.nio.file.DirectoryStream[java.nio.file.Path]: ...
    def newFileChannel(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], set: java.util.Set[java.nio.file.OpenOption], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> java.nio.channels.FileChannel: ...
    @typing.overload
    def newFileSystem(self, uRI: java.net.URI, map: typing.Union[java.util.Map[str, typing.Any], typing.Mapping[str, typing.Any]]) -> java.nio.file.FileSystem: ...
    @typing.overload
    def newFileSystem(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], map: typing.Union[java.util.Map[str, typing.Any], typing.Mapping[str, typing.Any]]) -> java.nio.file.FileSystem: ...
    def newInputStream(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], openOptionArray: typing.List[java.nio.file.OpenOption]) -> java.io.InputStream: ...
    def newOutputStream(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], openOptionArray: typing.List[java.nio.file.OpenOption]) -> java.io.OutputStream: ...
    _readAttributes_0__A = typing.TypeVar('_readAttributes_0__A', bound=java.nio.file.attribute.BasicFileAttributes)  # <A>
    @typing.overload
    def readAttributes(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], class_: typing.Type[_readAttributes_0__A], linkOptionArray: typing.List[java.nio.file.LinkOption]) -> _readAttributes_0__A: ...
    @typing.overload
    def readAttributes(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], string: str, linkOptionArray: typing.List[java.nio.file.LinkOption]) -> java.util.Map[str, typing.Any]: ...
    def readSymbolicLink(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> java.nio.file.Path: ...
    def setAttribute(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath], string: str, object: typing.Any, linkOptionArray: typing.List[java.nio.file.LinkOption]) -> None: ...

class FileTypeDetector:
    def probeContentType(self, path: typing.Union[java.nio.file.Path, jpype.protocol.SupportsPath]) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.nio.file.spi")``.

    FileSystemProvider: typing.Type[FileSystemProvider]
    FileTypeDetector: typing.Type[FileTypeDetector]



import java.io
import java.lang
import scala
import scala.collection
import scala.collection.generic
import scala.collection.immutable
import scala.collection.mutable
import scala.runtime
import scala.sys.process
import typing



class ShutdownHookThread(java.lang.Thread):
    def __init__(self, name: str): ...
    @staticmethod
    def apply(body: scala.Function0[scala.runtime.BoxedUnit]) -> 'ShutdownHookThread': ...
    def remove(self) -> bool: ...

class SystemProperties(scala.collection.mutable.AbstractMap[str, str]):
    def __init__(self): ...
    @typing.overload
    def $minus$eq(self, elem1: typing.Any, elem2: typing.Any, elems: scala.collection.Seq[typing.Any]) -> scala.collection.generic.Shrinkable[typing.Any]: ...
    @typing.overload
    def $minus$eq(self, key: str) -> 'SystemProperties': ...
    @typing.overload
    def $plus$eq(self, elem1: typing.Any, elem2: typing.Any, elems: scala.collection.Seq) -> scala.collection.generic.Growable: ...
    @typing.overload
    def $plus$eq(self, kv: scala.Tuple2[str, str]) -> 'SystemProperties': ...
    def contains(self, key: str) -> bool: ...
    def default(self, key: str) -> str: ...
    def empty(self) -> scala.collection.mutable.Map[str, str]: ...
    _exclusively__T = typing.TypeVar('_exclusively__T')  # <T>
    @staticmethod
    def exclusively(body: scala.Function0[_exclusively__T]) -> _exclusively__T: ...
    def get(self, key: str) -> scala.Option[str]: ...
    @staticmethod
    def headless() -> 'BooleanProp': ...
    @staticmethod
    def help(key: str) -> str: ...
    def iterator(self) -> scala.collection.Iterator[scala.Tuple2[str, str]]: ...
    def names(self) -> scala.collection.Iterator[str]: ...
    @staticmethod
    def noTraceSuppression() -> 'BooleanProp': ...
    @staticmethod
    def noTraceSupression() -> 'BooleanProp': ...
    @staticmethod
    def preferIPv4Stack() -> 'BooleanProp': ...
    @staticmethod
    def preferIPv6Addresses() -> 'BooleanProp': ...
    @staticmethod
    def systemPropertiesToCompanion(p: 'SystemProperties') -> 'SystemProperties.': ...
    _wrapAccess__T = typing.TypeVar('_wrapAccess__T')  # <T>
    def wrapAccess(self, body: scala.Function0[_wrapAccess__T]) -> scala.Option[_wrapAccess__T]: ...
    class : ...

class package:
    @staticmethod
    def addShutdownHook(body: scala.Function0[scala.runtime.BoxedUnit]) -> ShutdownHookThread: ...
    @staticmethod
    def allThreads() -> scala.collection.IndexedSeq[java.lang.Thread]: ...
    @staticmethod
    def env() -> scala.collection.immutable.Map[str, str]: ...
    @staticmethod
    def error(message: str) -> scala.runtime.Nothing.: ...
    @typing.overload
    @staticmethod
    def exit() -> scala.runtime.Nothing.: ...
    @typing.overload
    @staticmethod
    def exit(status: int) -> scala.runtime.Nothing.: ...
    @staticmethod
    def props() -> SystemProperties: ...
    @staticmethod
    def runtime() -> java.lang.Runtime: ...

class BooleanProp(scala.sys.Prop[typing.Any]):
    @staticmethod
    def booleanPropAsBoolean(b: 'BooleanProp') -> bool: ...
    @staticmethod
    def constant(key: str, isOn: bool) -> 'BooleanProp': ...
    def disable(self) -> None: ...
    def enable(self) -> None: ...
    _keyExists__T = typing.TypeVar('_keyExists__T')  # <T>
    @staticmethod
    def keyExists(key: str) -> 'BooleanProp': ...
    def toggle(self) -> None: ...
    @typing.overload
    def value(self) -> bool: ...
    @typing.overload
    def value(self) -> typing.Any: ...
    _valueIsTrue__T = typing.TypeVar('_valueIsTrue__T')  # <T>
    @staticmethod
    def valueIsTrue(key: str) -> 'BooleanProp': ...
    class BooleanPropImpl(scala.sys.PropImpl[typing.Any], scala.sys.BooleanProp):
        def __init__(self, key: str, valueFn: scala.Function1[str, typing.Any]): ...
        def disable(self) -> None: ...
        def enable(self) -> None: ...
        _setValue__T1 = typing.TypeVar('_setValue__T1')  # <T1>
        def setValue(self, newValue: _setValue__T1) -> bool: ...
        def toggle(self) -> None: ...
        def value(self) -> typing.Any: ...
    class ConstantImpl(scala.sys.BooleanProp):
        def __init__(self, key: str, value: bool): ...
        def clear(self) -> None: ...
        def disable(self) -> None: ...
        def enable(self) -> None: ...
        def get(self) -> str: ...
        def isSet(self) -> bool: ...
        def key(self) -> str: ...
        def option(self) -> scala.Option[typing.Any]: ...
        def set(self, newValue: str) -> str: ...
        _setValue__T1 = typing.TypeVar('_setValue__T1')  # <T1>
        def setValue(self, newValue: _setValue__T1) -> bool: ...
        def toggle(self) -> None: ...
        def value(self) -> bool: ...
        def zero(self) -> bool: ...

_CreatorImpl__T = typing.TypeVar('_CreatorImpl__T')  # <T>
class CreatorImpl(scala.sys.Prop.Creator[_CreatorImpl__T], typing.Generic[_CreatorImpl__T]):
    def __init__(self, f: scala.Function1[str, _CreatorImpl__T]): ...
    def apply(self, key: str) -> 'Prop'[_CreatorImpl__T]: ...

_Prop__Creator__T = typing.TypeVar('_Prop__Creator__T')  # <T>
_Prop__T = typing.TypeVar('_Prop__T')  # <T>
class Prop(typing.Generic[_Prop__T]):
    _apply__T = typing.TypeVar('_apply__T')  # <T>
    @staticmethod
    def apply(key: str, evidence$1: 'Prop.Creator'[_apply__T]) -> 'Prop'[_apply__T]: ...
    def clear(self) -> None: ...
    def get(self) -> str: ...
    def isSet(self) -> bool: ...
    def key(self) -> str: ...
    def option(self) -> scala.Option[_Prop__T]: ...
    def set(self, newValue: str) -> str: ...
    _setValue__T1 = typing.TypeVar('_setValue__T1')  # <T1>
    def setValue(self, value: _setValue__T1) -> _Prop__T: ...
    def value(self) -> _Prop__T: ...
    def zero(self) -> _Prop__T: ...
    class Creator(typing.Generic[_Prop__Creator__T]):
        def apply(self, key: str) -> 'Prop'[_Prop__Creator__T]: ...
    class DoubleProp$(CreatorImpl[typing.Any]):
        MODULE$: typing.ClassVar['Prop.DoubleProp.'] = ...
        def __init__(self): ...
    class FileProp$(CreatorImpl[java.io.File]):
        MODULE$: typing.ClassVar['Prop.FileProp.'] = ...
        def __init__(self): ...
    class IntProp$(CreatorImpl[typing.Any]):
        MODULE$: typing.ClassVar['Prop.IntProp.'] = ...
        def __init__(self): ...
    class StringProp$(CreatorImpl[str]):
        MODULE$: typing.ClassVar['Prop.StringProp.'] = ...
        def __init__(self): ...

_PropImpl__T = typing.TypeVar('_PropImpl__T')  # <T>
class PropImpl(Prop[_PropImpl__T], typing.Generic[_PropImpl__T]):
    def __init__(self, key: str, valueFn: scala.Function1[str, _PropImpl__T]): ...
    def clear(self) -> None: ...
    def get(self) -> str: ...
    def isSet(self) -> bool: ...
    def key(self) -> str: ...
    def option(self) -> scala.Option[_PropImpl__T]: ...
    def set(self, newValue: str) -> str: ...
    _setValue__T1 = typing.TypeVar('_setValue__T1')  # <T1>
    def setValue(self, newValue: _setValue__T1) -> _PropImpl__T: ...
    def toString(self) -> str: ...
    def underlying(self) -> scala.collection.mutable.Map[str, str]: ...
    def value(self) -> _PropImpl__T: ...
    def zero(self) -> _PropImpl__T: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.sys")``.

    BooleanProp: typing.Type[BooleanProp]
    CreatorImpl: typing.Type[CreatorImpl]
    Prop: typing.Type[Prop]
    PropImpl: typing.Type[PropImpl]
    ShutdownHookThread: typing.Type[ShutdownHookThread]
    SystemProperties: typing.Type[SystemProperties]
    package: typing.Type[package]
    process: scala.sys.process.__module_protocol__



import java.io
import java.lang
import java.security
import java.security.cert
import java.util
import java.util.stream
import java.util.zip
import jpype.protocol
import typing



class Attributes(java.util.Map[typing.Any, typing.Any], java.lang.Cloneable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, attributes: 'Attributes'): ...
    def clear(self) -> None: ...
    def clone(self) -> typing.Any: ...
    def containsKey(self, object: typing.Any) -> bool: ...
    def containsValue(self, object: typing.Any) -> bool: ...
    def entrySet(self) -> java.util.Set[java.util.Map.Entry[typing.Any, typing.Any]]: ...
    def equals(self, object: typing.Any) -> bool: ...
    def get(self, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getValue(self, string: str) -> str: ...
    @typing.overload
    def getValue(self, name: 'Attributes.Name') -> str: ...
    def hashCode(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> java.util.Set[typing.Any]: ...
    def put(self, object: typing.Any, object2: typing.Any) -> typing.Any: ...
    def putAll(self, map: typing.Union[java.util.Map[typing.Any, typing.Any], typing.Mapping[typing.Any, typing.Any]]) -> None: ...
    def putValue(self, string: str, string2: str) -> str: ...
    @typing.overload
    def remove(self, object: typing.Any, object2: typing.Any) -> bool: ...
    @typing.overload
    def remove(self, object: typing.Any) -> typing.Any: ...
    def size(self) -> int: ...
    def values(self) -> java.util.Collection[typing.Any]: ...
    class Name:
        MANIFEST_VERSION: typing.ClassVar['Attributes.Name'] = ...
        SIGNATURE_VERSION: typing.ClassVar['Attributes.Name'] = ...
        CONTENT_TYPE: typing.ClassVar['Attributes.Name'] = ...
        CLASS_PATH: typing.ClassVar['Attributes.Name'] = ...
        MAIN_CLASS: typing.ClassVar['Attributes.Name'] = ...
        SEALED: typing.ClassVar['Attributes.Name'] = ...
        EXTENSION_LIST: typing.ClassVar['Attributes.Name'] = ...
        EXTENSION_NAME: typing.ClassVar['Attributes.Name'] = ...
        EXTENSION_INSTALLATION: typing.ClassVar['Attributes.Name'] = ...
        IMPLEMENTATION_TITLE: typing.ClassVar['Attributes.Name'] = ...
        IMPLEMENTATION_VERSION: typing.ClassVar['Attributes.Name'] = ...
        IMPLEMENTATION_VENDOR: typing.ClassVar['Attributes.Name'] = ...
        IMPLEMENTATION_VENDOR_ID: typing.ClassVar['Attributes.Name'] = ...
        IMPLEMENTATION_URL: typing.ClassVar['Attributes.Name'] = ...
        SPECIFICATION_TITLE: typing.ClassVar['Attributes.Name'] = ...
        SPECIFICATION_VERSION: typing.ClassVar['Attributes.Name'] = ...
        SPECIFICATION_VENDOR: typing.ClassVar['Attributes.Name'] = ...
        MULTI_RELEASE: typing.ClassVar['Attributes.Name'] = ...
        def __init__(self, string: str): ...
        def equals(self, object: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...

class JarEntry(java.util.zip.ZipEntry):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, jarEntry: 'JarEntry'): ...
    @typing.overload
    def __init__(self, zipEntry: java.util.zip.ZipEntry): ...
    def getAttributes(self) -> Attributes: ...
    def getCertificates(self) -> typing.List[java.security.cert.Certificate]: ...
    def getCodeSigners(self) -> typing.List[java.security.CodeSigner]: ...
    def getRealName(self) -> str: ...

class JarException(java.util.zip.ZipException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class JarFile(java.util.zip.ZipFile):
    MANIFEST_NAME: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath]): ...
    @typing.overload
    def __init__(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath], boolean: bool): ...
    @typing.overload
    def __init__(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath], boolean: bool, int: int): ...
    @typing.overload
    def __init__(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath], boolean: bool, int: int, version: java.lang.Runtime.Version): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, boolean: bool): ...
    @staticmethod
    def baseVersion() -> java.lang.Runtime.Version: ...
    def entries(self) -> java.util.Enumeration[JarEntry]: ...
    def getEntry(self, string: str) -> java.util.zip.ZipEntry: ...
    def getInputStream(self, zipEntry: java.util.zip.ZipEntry) -> java.io.InputStream: ...
    def getJarEntry(self, string: str) -> JarEntry: ...
    def getManifest(self) -> 'Manifest': ...
    def getVersion(self) -> java.lang.Runtime.Version: ...
    def isMultiRelease(self) -> bool: ...
    @staticmethod
    def runtimeVersion() -> java.lang.Runtime.Version: ...
    def stream(self) -> java.util.stream.Stream[JarEntry]: ...
    def versionedStream(self) -> java.util.stream.Stream[JarEntry]: ...

class JarInputStream(java.util.zip.ZipInputStream):
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, boolean: bool): ...
    def getManifest(self) -> 'Manifest': ...
    def getNextEntry(self) -> java.util.zip.ZipEntry: ...
    def getNextJarEntry(self) -> JarEntry: ...
    @typing.overload
    def read(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def read(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    @typing.overload
    def read(self) -> int: ...

class JarOutputStream(java.util.zip.ZipOutputStream):
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, manifest: 'Manifest'): ...
    def putNextEntry(self, zipEntry: java.util.zip.ZipEntry) -> None: ...

class Manifest(java.lang.Cloneable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream): ...
    @typing.overload
    def __init__(self, manifest: 'Manifest'): ...
    def clear(self) -> None: ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAttributes(self, string: str) -> Attributes: ...
    def getEntries(self) -> java.util.Map[str, Attributes]: ...
    def getMainAttributes(self) -> Attributes: ...
    def hashCode(self) -> int: ...
    def read(self, inputStream: java.io.InputStream) -> None: ...
    def write(self, outputStream: java.io.OutputStream) -> None: ...

class Pack200:
    @staticmethod
    def newPacker() -> 'Pack200.Packer': ...
    @staticmethod
    def newUnpacker() -> 'Pack200.Unpacker': ...
    class Packer:
        SEGMENT_LIMIT: typing.ClassVar[str] = ...
        KEEP_FILE_ORDER: typing.ClassVar[str] = ...
        EFFORT: typing.ClassVar[str] = ...
        DEFLATE_HINT: typing.ClassVar[str] = ...
        MODIFICATION_TIME: typing.ClassVar[str] = ...
        PASS_FILE_PFX: typing.ClassVar[str] = ...
        UNKNOWN_ATTRIBUTE: typing.ClassVar[str] = ...
        CLASS_ATTRIBUTE_PFX: typing.ClassVar[str] = ...
        FIELD_ATTRIBUTE_PFX: typing.ClassVar[str] = ...
        METHOD_ATTRIBUTE_PFX: typing.ClassVar[str] = ...
        CODE_ATTRIBUTE_PFX: typing.ClassVar[str] = ...
        PROGRESS: typing.ClassVar[str] = ...
        KEEP: typing.ClassVar[str] = ...
        PASS: typing.ClassVar[str] = ...
        STRIP: typing.ClassVar[str] = ...
        ERROR: typing.ClassVar[str] = ...
        TRUE: typing.ClassVar[str] = ...
        FALSE: typing.ClassVar[str] = ...
        LATEST: typing.ClassVar[str] = ...
        @typing.overload
        def pack(self, jarFile: JarFile, outputStream: java.io.OutputStream) -> None: ...
        @typing.overload
        def pack(self, jarInputStream: JarInputStream, outputStream: java.io.OutputStream) -> None: ...
        def properties(self) -> java.util.SortedMap[str, str]: ...
    class Unpacker:
        KEEP: typing.ClassVar[str] = ...
        TRUE: typing.ClassVar[str] = ...
        FALSE: typing.ClassVar[str] = ...
        DEFLATE_HINT: typing.ClassVar[str] = ...
        PROGRESS: typing.ClassVar[str] = ...
        def properties(self) -> java.util.SortedMap[str, str]: ...
        @typing.overload
        def unpack(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath], jarOutputStream: JarOutputStream) -> None: ...
        @typing.overload
        def unpack(self, inputStream: java.io.InputStream, jarOutputStream: JarOutputStream) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.util.jar")``.

    Attributes: typing.Type[Attributes]
    JarEntry: typing.Type[JarEntry]
    JarException: typing.Type[JarException]
    JarFile: typing.Type[JarFile]
    JarInputStream: typing.Type[JarInputStream]
    JarOutputStream: typing.Type[JarOutputStream]
    Manifest: typing.Type[Manifest]
    Pack200: typing.Type[Pack200]



import scorex.crypto.authds.legacy.avltree
import scorex.crypto.authds.legacy.treap
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scorex.crypto.authds.legacy")``.

    avltree: scorex.crypto.authds.legacy.avltree.__module_protocol__
    treap: scorex.crypto.authds.legacy.treap.__module_protocol__



import com.typesafe.scalalogging
import java.lang
import scala.collection
import scala.collection.generic
import scala.math
import scala.reflect
import scorex.util.encode
import scorex.util.serialization
import supertagged
import typing



class ByteArrayBuilder:
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def append(self, boolean: bool) -> 'ByteArrayBuilder': ...
    @typing.overload
    def append(self, byte: int) -> 'ByteArrayBuilder': ...
    @typing.overload
    def append(self, byteArray: typing.List[int]) -> 'ByteArrayBuilder': ...
    @typing.overload
    def append(self, byteArray: typing.List[int], int: int, int2: int) -> 'ByteArrayBuilder': ...
    @typing.overload
    def append(self, char: str) -> 'ByteArrayBuilder': ...
    @typing.overload
    def append(self, int: int) -> 'ByteArrayBuilder': ...
    @typing.overload
    def append(self, long: int) -> 'ByteArrayBuilder': ...
    @typing.overload
    def append(self, short: int) -> 'ByteArrayBuilder': ...
    def array(self) -> typing.List[int]: ...
    def byteAt(self, int: int) -> int: ...
    def capacity(self) -> int: ...
    def crop(self, int: int) -> None: ...
    def length(self) -> int: ...
    def setLength(self, int: int) -> None: ...
    def toBytes(self) -> typing.List[int]: ...
    def trim(self) -> typing.List[int]: ...

_Extensions__TraversableOps__A = typing.TypeVar('_Extensions__TraversableOps__A')  # <A>
_Extensions__TraversableOps__Source = typing.TypeVar('_Extensions__TraversableOps__Source', bound=scala.collection.Traversable)  # <Source>
class Extensions:
    class ByteOps:
        def __init__(self, b: int): ...
        def b(self) -> int: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def toUByte(self) -> int: ...
    class ByteOps$:
        MODULE$: typing.ClassVar['Extensions.ByteOps.'] = ...
        def __init__(self): ...
        def equals$extension(self, $this: int, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: int) -> int: ...
        def toUByte$extension(self, $this: int) -> int: ...
    class IntOps:
        def __init__(self, x: int): ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def toByteExact(self) -> int: ...
        def toShortExact(self) -> int: ...
        def x(self) -> int: ...
    class IntOps$:
        MODULE$: typing.ClassVar['Extensions.IntOps.'] = ...
        def __init__(self): ...
        def equals$extension(self, $this: int, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: int) -> int: ...
        def toByteExact$extension(self, $this: int) -> int: ...
        def toShortExact$extension(self, $this: int) -> int: ...
    class LongOps:
        def __init__(self, x: int): ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def toByteExact(self) -> int: ...
        def toIntExact(self) -> int: ...
        def toShortExact(self) -> int: ...
        def x(self) -> int: ...
    class LongOps$:
        MODULE$: typing.ClassVar['Extensions.LongOps.'] = ...
        def __init__(self): ...
        def equals$extension(self, $this: int, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: int) -> int: ...
        def toByteExact$extension(self, $this: int) -> int: ...
        def toIntExact$extension(self, $this: int) -> int: ...
        def toShortExact$extension(self, $this: int) -> int: ...
    class ShortOps:
        def __init__(self, x: int): ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def toByteExact(self) -> int: ...
        def x(self) -> int: ...
    class ShortOps$:
        MODULE$: typing.ClassVar['Extensions.ShortOps.'] = ...
        def __init__(self): ...
        def equals$extension(self, $this: int, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: int) -> int: ...
        def toByteExact$extension(self, $this: int) -> int: ...
    class TraversableOps(typing.Generic[_Extensions__TraversableOps__A, _Extensions__TraversableOps__Source]):
        def __init__(self, xs: _Extensions__TraversableOps__Source): ...
        _cast__B = typing.TypeVar('_cast__B')  # <B>
        def cast(self, evidence$1: scala.reflect.ClassTag[_cast__B], cbf: scala.collection.generic.CanBuildFrom[_Extensions__TraversableOps__Source, _cast__B, _Extensions__TraversableOps__Source]) -> _Extensions__TraversableOps__Source: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def xs(self) -> _Extensions__TraversableOps__Source: ...
    class TraversableOps$:
        MODULE$: typing.ClassVar['Extensions.TraversableOps.'] = ...
        def __init__(self): ...
        _cast$extension__B = typing.TypeVar('_cast$extension__B')  # <B>
        _cast$extension__A = typing.TypeVar('_cast$extension__A')  # <A>
        _cast$extension__Source = typing.TypeVar('_cast$extension__Source', bound=scala.collection.Traversable)  # <Source>
        def cast$extension(self, $this: _cast.extension__Source, evidence$1: scala.reflect.ClassTag[_cast.extension__B], cbf: scala.collection.generic.CanBuildFrom[_cast.extension__Source, _cast.extension__B, _cast.extension__Source]) -> _cast.extension__Source: ...
        _equals$extension__A = typing.TypeVar('_equals$extension__A')  # <A>
        _equals$extension__Source = typing.TypeVar('_equals$extension__Source', bound=scala.collection.Traversable)  # <Source>
        def equals$extension(self, $this: _equals.extension__Source, x$1: typing.Any) -> bool: ...
        _hashCode$extension__A = typing.TypeVar('_hashCode$extension__A')  # <A>
        _hashCode$extension__Source = typing.TypeVar('_hashCode$extension__Source', bound=scala.collection.Traversable)  # <Source>
        def hashCode$extension(self, $this: _hashCode.extension__Source) -> int: ...

class Random:
    @staticmethod
    def randomBytes(howMany: int) -> typing.List[int]: ...
    @staticmethod
    def randomBytes$default$1() -> int: ...

class ScorexEncoding:
    @staticmethod
    def $init$($this: 'ScorexEncoding') -> None: ...
    def encoder(self) -> scorex.util.encode.BytesEncoder: ...
    def scorex$util$ScorexEncoding$_setter_$encoder_$eq(self, x$1: scorex.util.encode.BytesEncoder) -> None: ...

class ScorexLogging(com.typesafe.scalalogging.StrictLogging):
    @staticmethod
    def $init$($this: 'ScorexLogging') -> None: ...
    def log(self) -> com.typesafe.scalalogging.Logger: ...

class package:
    @staticmethod
    def bytesToId(bytes: typing.List[int]) -> java.lang.String: ...
    @staticmethod
    def idToBytes(id: typing.Union[java.lang.String, str]) -> typing.List[int]: ...
    class ByteArrayOps:
        def __init__(self, b: typing.List[int]): ...
        def b(self) -> typing.List[int]: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def toModifierId(self) -> java.lang.String: ...
    class ByteArrayOps$:
        MODULE$: typing.ClassVar['package.ByteArrayOps.'] = ...
        def __init__(self): ...
        def equals$extension(self, $this: typing.List[int], x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: typing.List[int]) -> int: ...
        def toModifierId$extension(self, $this: typing.List[int]) -> java.lang.String: ...
    class ModifierId$(supertagged.package.TaggedType[java.lang.String]):
        MODULE$: typing.ClassVar['package.ModifierId.'] = ...
        def __init__(self): ...
        _$at$at__TagIn = typing.TypeVar('_$at$at__TagIn')  # <TagIn>
        _$at$at__Sub = typing.TypeVar('_$at$at__Sub')  # <Sub>
        _$at$at__C = typing.TypeVar('_$at$at__C')  # <C>
        def $at$at(self, c: _.at.at__C, tagger: supertagged.package.Tagger[_.at.at__TagIn, typing.Union[java.lang.String, str], supertagged.package.TaggedType, _.at.at__Sub, _.at.at__C]) -> typing.Any: ...
        _$bang$at$at__TagIn = typing.TypeVar('_$bang$at$at__TagIn')  # <TagIn>
        _$bang$at$at__Sub = typing.TypeVar('_$bang$at$at__Sub')  # <Sub>
        _$bang$at$at__C = typing.TypeVar('_$bang$at$at__C')  # <C>
        def $bang$at$at(self, c: _.bang.at.at__C, tagger: supertagged.package.Tagger[_.bang.at.at__TagIn, typing.Union[java.lang.String, str], supertagged.package.TaggedType, _.bang.at.at__Sub, _.bang.at.at__C]) -> typing.Any: ...
        _apply__TagIn = typing.TypeVar('_apply__TagIn')  # <TagIn>
        _apply__Sub = typing.TypeVar('_apply__Sub')  # <Sub>
        _apply__C = typing.TypeVar('_apply__C')  # <C>
        def apply(self, c: _apply__C, tagger: supertagged.package.Tagger[_apply__TagIn, typing.Union[java.lang.String, str], supertagged.package.TaggedType, _apply__Sub, _apply__C]) -> typing.Any: ...
        _ordering__U = typing.TypeVar('_ordering__U')  # <U>
        def ordering(self, origin: scala.math.Ordering[typing.Union[java.lang.String, str]]) -> scala.math.Ordering[java.lang.String]: ...
        def raw(self, c: typing.Any) -> typing.Any: ...
        _untag__TagIn = typing.TypeVar('_untag__TagIn')  # <TagIn>
        _untag__Sub = typing.TypeVar('_untag__Sub')  # <Sub>
        _untag__C = typing.TypeVar('_untag__C')  # <C>
        def untag(self, c: _untag__C, tagger: supertagged.package.Tagger[_untag__TagIn, typing.Union[java.lang.String, str], supertagged.package.TaggedType, _untag__Sub, _untag__C]) -> typing.Any: ...
    class ModifierIdOps:
        def __init__(self, m: typing.Union[java.lang.String, str]): ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def m(self) -> java.lang.String: ...
        def toBytes(self) -> typing.List[int]: ...
    class ModifierIdOps$:
        MODULE$: typing.ClassVar['package.ModifierIdOps.'] = ...
        def __init__(self): ...
        def equals$extension(self, $this: typing.Union[java.lang.String, str], x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: typing.Union[java.lang.String, str]) -> int: ...
        def toBytes$extension(self, $this: typing.Union[java.lang.String, str]) -> typing.List[int]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scorex.util")``.

    ByteArrayBuilder: typing.Type[ByteArrayBuilder]
    Extensions: typing.Type[Extensions]
    Random: typing.Type[Random]
    ScorexEncoding: typing.Type[ScorexEncoding]
    ScorexLogging: typing.Type[ScorexLogging]
    package: typing.Type[package]
    encode: scorex.util.encode.__module_protocol__
    serialization: scorex.util.serialization.__module_protocol__
